@@ -46,6 +46,7 @@ OC.L10N.register(
     "Failed to authorize" : "Ezin izan da baimendu",
     "Invalid folder path" : "Karpeta bide baliogabea",
     "Folder not found" : "Ez da karpeta aurkitu",
+    "No favorites" : "Gogokorik ez",
     "Upload (max. %s)" : "Igo (%s gehienez)",
     "Accept" : "Onartu",
     "Reject" : "Ukatu",
@@ -75,10 +76,11 @@ OC.L10N.register(
     "Your have used your space quota and cannot upload files anymore" : "Zure espazio-kuota erabili duzu eta ezin duzu fitxategi gehiago kargatu",
     "You don’t have permission to upload or create files here" : "Ez duzu baimenik fitxategiak hona kargatu edo hemen sortzeko",
     "Favorite" : "Gogokoa",
-    "\"{displayName}\" action executed successfully" : "\"{displayName}\" ekintza behar bezala exekutatu da",
-    "\"{displayName}\" action failed" : "\"{displayName}\" ekintzak huts egin du",
+    "Back" : "Itzuli",
     "Toggle selection for file \"{displayName}\"" : "Ordeztu hautatutakoa  \"{displayName}\" fitxategiarekin",
     "Toggle selection for folder \"{displayName}\"" : "Ordeztu hautatutakoa  \"{displayName}\" karpetarekin",
+    "File is loading" : "Fitxategia kargatzen ari da",
+    "Folder is loading" : "Karpeta kargatzen ari da",
     "Rename file" : "Berrizendatu fitxategia",
     "Filename" : "Fitxategi-izena",
     "Folder name" : "Karpetaren izena",
@@ -86,6 +88,7 @@ OC.L10N.register(
     "Another entry with the same name already exists." : "Izen bereko beste sarrera bat badago jada.",
     "Invalid filename." : "Fitxategi-izen baliogabea.",
     "Renamed \"{oldName}\" to \"{newName}\"" : "\"{oldName}\" \"{newName}\"(e)ra berrizendatu da.",
+    "Unknown date" : "Data ezezaguna",
     "Pending" : "Zain",
     "Clear filter" : "Garbitu iragazkia",
     "Modified" : "Aldatuta",
@@ -100,8 +103,11 @@ OC.L10N.register(
     "(selected)" : "(hautatuta)",
     "\"{displayName}\" failed on some elements " : "\"{displayName}\"-k huts egin du elementu batzuetan",
     "\"{displayName}\" batch action executed successfully" : "\"{displayName}\" multzoko ekintza behar bezala exekutatu da",
+    "\"{displayName}\" action failed" : "\"{displayName}\" ekintzak huts egin du",
     "{count} selected" : "{count} hautatuta",
     "List of files and folders." : "Fitxategi eta karpeten zerrenda.",
+    "You don’t have permission to upload or create files here." : "Ez duzu baimenik fitxategiak hona kargatu edo hemen sortzeko.",
+    "You have used your space quota and cannot upload files anymore." : "Zure espazio-kuota erabili duzu eta ezin duzu fitxategi gehiago kargatu.",
     "Column headers with buttons are sortable." : "Botoiak dituzten zutabeen goiburuak ordena daitezke.",
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Zerrenda hau ez da guztiz ikusten errendimendu arrazoiengatik. Fitxategiak zerrendan zehar nabigatzen duten heinean bistaratuko dira.",
     "File not found" : "Ez da fitxategia aurkitu",
@@ -132,7 +138,6 @@ OC.L10N.register(
     "Cannot transfer ownership of a file or folder you do not own" : "Ezin da zurea ez den fitxategi edo karpeta baten jabetza transferitu",
     "Select file or folder to link to" : "Hautatu estekatzeko fitxategia edo karpeta",
     "Choose {file}" : "Aukeratu {file}",
-    "New" : "Berria",
     "Loading current folder" : "Uneko karpeta kargatzen",
     "Retry" : "saiatu berriro",
     "No files in here" : "Ez dago fitxategirik hemen",
@@ -149,6 +154,7 @@ OC.L10N.register(
     "Error during upload: {message}" : "Errorea igotzean: {message}",
     "Error during upload, status code {status}" : "Errore bat gertatu da igotzean, {status} egoera kodea",
     "Unknown error during upload" : "Errore ezezaguna igotzean",
+    "\"{displayName}\" action executed successfully" : "\"{displayName}\" ekintza behar bezala exekutatu da",
     "Filter filenames…" : "Iragazi fitxategi-izenak...",
     "Views" : "Ikuspegiak",
     "Files settings" : "FItxategien ezarpenak",
@@ -168,6 +174,28 @@ OC.L10N.register(
     "Copy to clipboard" : "Kopiatu arbelera",
     "Use this address to access your Files via WebDAV" : "Erabili helbide hau WebDAV bidez zure fitxategietara sartzeko",
     "If you have enabled 2FA, you must create and use a new app password by clicking here." : "2FA gaitu baduzu, aplikazioaren pasahitz berria sortu eta erabili behar duzu hemen klik eginez.",
+    "Keyboard shortcuts" : "Teklatuaren lasterbideak",
+    "Speed up your Files experience with these quick shortcuts." : "Azkartu zure Fitxategi esperientzia lasterbide bizkor hauekin",
+    "Open the actions menu for a file" : "Ireki ekintza menua fitxategi baterako",
+    "Rename a file" : "Fitxategi bat berrizendatu",
+    "Delete a file" : "Fitxategi bat ezabatu",
+    "Favorite or remove a file from favorites" : "Fitxategi bat gustoko bihurtu edo gustoko izateari utzi",
+    "Manage tags for a file" : "Fitxategi baten etiketak kudeatu",
+    "Selection" : "Hautapena",
+    "Select all files" : "Fitxategi guztiak aukeratu",
+    "Deselect all files" : "Fitxategi guztiak desaukeratu",
+    "Select or deselect a file" : "Fitxategi bat aukeratu edo desaukeratu",
+    "Select a range of files" : "Fitxategi-hein bat aukeratu",
+    "Navigation" : "Nabigazioa",
+    "Navigate to the parent folder" : "Nabigatu guraso karpetara",
+    "Navigate to the file above" : "Nabigatu goiko fitxategira",
+    "Navigate to the file below" : "Nabigatu azpiko fitxategira",
+    "Navigate to the file on the left (in grid mode)" : "Nabigatu ezkerreko fitxategira (sareta moduan)",
+    "Navigate to the file on the right (in grid mode)" : "Nabigatu eskuineko fitxategira (sareta moduan)",
+    "View" : "Ikusi",
+    "Toggle the grid view" : "Txandakatu sareta ikuspegia",
+    "Open the sidebar for a file" : "Ireki alboko barra fitxategi baterako",
+    "Show those shortcuts" : "Erakutsi lasterbide horiek",
     "Clipboard is not available" : "Arbela ez dago erabilgarri",
     "WebDAV URL copied to clipboard" : "WebDAV URLa arbelean kopiatu da",
     "Owner" : "Jabea",
@@ -184,12 +212,12 @@ OC.L10N.register(
     "Blank" : "Hutsik",
     "Unable to create new file from template" : "Ezin da fitxategi berria sortu txantiloitik",
     "Deletion cancelled" : "Ezabatzea bertan behera utzi da",
-    "Delete permanently" : "Ezabatu betirako",
-    "Delete and unshare" : "Ezabatu eta kendu partekatzea",
     "Leave this share" : "Utzi partekatze hau",
     "Leave these shares" : "Utzi partekatze hauek",
     "Disconnect storage" : "Deskonektatu biltegia",
     "Disconnect storages" : "Deskonektatu biltegiak",
+    "Delete permanently" : "Ezabatu betirako",
+    "Delete and unshare" : "Ezabatu eta kendu partekatzea",
     "Delete file" : "Fitxategia ezabatu",
     "Delete files" : "Ezabatu fitxategiak",
     "Delete folder" : "Ezabatu karpeta",
@@ -200,11 +228,13 @@ OC.L10N.register(
     "Confirm deletion" : "Berretsi ezabaketa",
     "Cancel" : "Utzi",
     "Edit file locally" : "Editatu fitxategia lokalean",
-    "The file should now open locally. If you don't see this happening, make sure that the desktop client is installed on your system." : "Orain fitxategiak modu lokalean ireki behar luke. Ez bada hori gertatzen, ziurta ezazu mahaigaineko bezeroa instalatuta daukazula zure sisteman.",
-    "Retry local edit" : "Saiatu berriro tokiko edizioa",
+    "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "Fitxategia orain zure gailuan ireki beharko litzateke. Hala ez bada, egiaztatu mahaigaineko aplikazioa instalatuta duzula.",
+    "Retry and close" : "Saiatu berriro eta itxi",
     "Edit online" : "Editatu sarean",
     "Failed to redirect to client" : "Bezerora birbideratzeak huts egin du",
     "Edit locally" : "Editatu lokalean",
+    "Moving \"{source}\" to \"{destination}\" …" : "«{source}» «{destination}»(e)ra mugitzen",
+    "Copying \"{source}\" to \"{destination}\" …" : "«{source}» «{destination}»(e)ra mugitzen",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "Ezin duzu fitxategi/karpeta bat berera edo bere azpikarpeta batera mugitu",
     "(copy)" : "(kopiatu)",
     "(copy %n)" : "(kopiatu %n)",
@@ -237,6 +267,7 @@ OC.L10N.register(
     "PDFs" : "PDFak",
     "Folders" : "Karpetak",
     "Audio" : "Audio",
+    "Photos and images" : "Argazkiak eta irudiak",
     "Videos" : "Bideoak",
     "New folder creation cancelled" : "Karpeta berrien sorrera bertan behera utzi da",
     "Created new folder \"{name}\"" : "\"{name}\" karpeta berria sortu da",
@@ -259,19 +290,28 @@ OC.L10N.register(
     "Files moved successfully" : "Fitxategiak behar bezala mugitu dira",
     "Conflicts resolution skipped" : "Gatazkak konpontzea saihestu da",
     "Upload cancelled" : "Igotzea bertan behera utzi da",
+    "Adding the file extension \"{new}\" may render the file unreadable." : "«{new}» fitxategiaren luzapena gehitzeak fitxategia irakurezin bihur dezake.",
+    "Removing the file extension \"{old}\" may render the file unreadable." : "«{old}» fitxategiaren luzapena kentzeak fitxategia irakurezin bihur dezake.",
+    "Changing the file extension from \"{old}\" to \"{new}\" may render the file unreadable." : "Fitxategiaren luzapena «{old}»(e)tik «{new}»(e)ra aldatzeak irakurezin bihur dezake.",
+    "Change file extension" : "Aldatu fitxategiaren luzapena",
+    "Keep {oldextension}" : "Mantendu {oldextension}",
+    "Use {newextension}" : "Erabili {newextension}",
+    "Remove extension" : "Kendu luzapena",
     "This operation is forbidden" : "Eragiketa hau debekatuta dago",
     "This directory is unavailable, please check the logs or contact the administrator" : "Direktorio hau ez dago erabilgarri, egiaztatu egunkariak edo jarri administratzailearekin harremanetan",
     "Storage is temporarily not available" : "Biltegia ez dago erabilgarri aldi baterako",
+    "Unexpected error: {error}" : "Ustekabeko errorea: {error}",
     "_{folderCount} folder_::_{folderCount} folders_" : ["Karpeta {folderCount}","{folderCount} karpeta"],
     "_{fileCount} file_::_{fileCount} files_" : ["Fitxategi {fileCount}","{fileCount} fitxategi"],
     "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["Fitxategi 1 eta karpeta {folderCount}","Fitxategi 1 eta {folderCount} karpeta"],
     "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["Fitxategi {fileCount} eta karpeta 1","{fileCount} fitxategi eta karpeta 1"],
     "{fileCount} files and {folderCount} folders" : "{fileCount} fitxategi eta {folderCount} fitxategi",
     "Filename must not be empty." : "Fitxategi-izenak ez du hutsik egon behar.",
-    "\"{char}\" is not allowed inside a filename." : "\"{char}\" ez da onartzen fitxategi-izen baten barruan..",
+    "\"{char}\" is not allowed inside a filename." : "\"{char}\" ez da onartzen fitxategi-izen baten barruan.",
     "\"{segment}\" is a reserved name and not allowed for filenames." : "\"{segment}\" izen erreserbatua da eta ez da onartzen fitxategi-izenetan.",
     "\"{extension}\" is not an allowed filetype." : "\"{extension}\" fitxategi mota ez dago baimenduta.",
     "Filenames must not end with \"{extension}\"." : "Fitxategi-izenak ez dira \"{extension}\"rekin amaitu behar..",
+    "List of favorite files and folders." : "Gogoko fitxategi eta karpeten zerrenda.",
     "No favorites yet" : "Gogokorik ez oraindik",
     "Files and folders you mark as favorite will show up here" : "Gogokotzat markatutako fitxategi eta karpetak hemen agertuko dira",
     "All files" : "Fitxategi guztiak",
@@ -344,6 +384,7 @@ OC.L10N.register(
     "{dirs} and {files}" : "{dirs} eta {files}",
     "_including %n hidden_::_including %n hidden_" : ["ezkutuko %n barne","ezkutuko %n barne"],
     "_Uploading %n file_::_Uploading %n files_" : ["Fitxategi %n kargatzen","%n fitxategi igotzen"],
+    "New" : "Berria",
     "New file/folder menu" : "Fitxategi/karpeta berri menua",
     "Select file range" : "Hautatu fitxategi-barrutia",
     "{used}%" : "%{used}",
@@ -371,6 +412,10 @@ OC.L10N.register(
     "An error occurred while trying to update the tags" : "Errore bat gertatu da etiketak eguneratzen saiatzean",
     "\"remote user\"" : "\"urruneko erabiltzailea\"",
     "{newName} already exists." : "{newName} badago aurretik.",
+    "\"{segment}\" is not allowed inside a filename." : "«{segment}» ez da onartzen fitxategi-izen baten barruan.",
+    "\"{segment}\" is a forbidden file or folder name." : "«{segment}» debekatutako fitxategi edo karpeta-izen bat da.",
+    "\"{segment}\" is not an allowed filetype." : "«{segment}» fitxategi-mota ez da onartzen.",
+    "Filenames must not end with \"{segment}\"." : "Fitxategi-izenak ez dira «{segment}»(e)rekin amaitu behar.",
     "Name cannot be empty" : "Izena ezin da hutsik egon",
     "Another entry with the same name already exists" : "Badago izen hori duen beste sarrera bat",
     "Could not rename \"{oldName}\", it does not exist any more" : "Ezin izan da \"{oldName}\" berrizendatu, ez da existitzen dagoeneko",
@@ -388,6 +433,9 @@ OC.L10N.register(
     "Text file" : "Testu-fitxategia",
     "New text file.txt" : "Testu-fitxategi berria.txt",
     "Direct link was copied (only works for people who have access to this file/folder)" : "Esteka zuzena kopiatu da (fitxategi/karpeta honetara sarbidea dutenentzat bakarrik balio du)",
-    "Copy direct link (only works for people who have access to this file/folder)" : "Kopiatu esteka zuzena (fitxategi/karpeta honetara sarbidea dutenentzat bakarrik balio du)"
+    "Copy direct link (only works for people who have access to this file/folder)" : "Kopiatu esteka zuzena (fitxategi/karpeta honetara sarbidea dutenentzat bakarrik balio du)",
+    "Favored" : "Mesedetua",
+    "Favor" : "Mesedea",
+    "Not favored" : "Mesedetu gabe"
 },
 "nplurals=2; plural=(n != 1);");
