@@ -74,7 +74,6 @@ OC.L10N.register(
     "Calendar" : "Calendario",
     "Personal info" : "Información Personal",
     "Email server" : "Servidor de correo electrónico",
-    "Security & setup warnings" : "Advertencias de seguridad y configuración",
     "Background jobs" : "Trabajos en segundo plano",
     "Unlimited" : "Ilimitado",
     "Verifying" : "Verificando",
@@ -83,6 +82,7 @@ OC.L10N.register(
     "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "Tu PHP no cuenta con soporte FreeType, lo que resulta en fallas en la imagen de perfil y la interface de configuraciones. ",
     "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP no parece estar configurado correctamente para consultar las variables de ambiente. La prueba con getenv(\"PATH\") sólo regresa una respuesta vacía.",
     "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Tu base de datos no puede correr con el nivel de aislamiento de transacción de \"READ COMMITTED\".  Puede causar problemas cuando mútiples acciones sean ejecutadas en paralelo.",
+    "Enable" : "Habilitar",
     "None" : "Ninguno",
     "Allow apps to use the Share API" : "Permitir que las aplicaciones usen el API para Compartir",
     "Allow resharing" : "Permitir volver a compartir",
@@ -97,7 +97,6 @@ OC.L10N.register(
     "Limit to groups" : "Limitar a grupos",
     "Save changes" : "Guardar cambios",
     "Remove" : "Eliminar",
-    "Disable" : "Deshabilitar",
     "Featured" : "Destacado",
     "Icon" : "Ícono",
     "Name" : "Nombre",
@@ -105,6 +104,8 @@ OC.L10N.register(
     "Level" : "Nivel",
     "Actions" : "Acciones",
     "No apps found for your version" : "No se encontraron aplicaciones para tu versión",
+    "Daemon" : "Demonio",
+    "Display Name" : "Nombre a desplegar",
     "Description" : "Descripción",
     "Details" : "Detalles",
     "All" : "Todos",
@@ -139,7 +140,6 @@ OC.L10N.register(
     "Error while creating device token" : "Se presentó un error al crear la ficha en el dispositivo",
     "Login" : "Iniciar sesión",
     "Password" : "Contraseña",
-    "Enable" : "Habilitar",
     "Server-side encryption" : "Encripción del lado del servidor",
     "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "La encripción del lado del servidor hace posible encriptar archivos que serán cargados a este servidor. Esto trae consigo algunas limitaciónes como penalizaciones en el desemeño, asi que habilítalo sólo si es necesario. ",
     "Enable server-side encryption" : "Habilitar encripción del lado del servidor",
@@ -170,11 +170,10 @@ OC.L10N.register(
     "Quota" : "Cuota",
     "Language" : "Idioma",
     "Avatar" : "Avatar",
-    "Username" : "Usuario",
     "Group admin for" : "Administrador del grupo para",
-    "User backend" : "Backend del usuario",
     "Storage location" : "Úbicación del almacenamiento",
     "Last login" : "Último inicio de sesión",
+    "Account actions" : "Acciones de la cuenta",
     "{size} used" : "{size} usado",
     "Done" : "Terminado",
     "Edit" : "Editar",
@@ -198,8 +197,11 @@ OC.L10N.register(
     "Updates" : "Actualizaciones",
     "App bundles" : "Paquetes de aplicación",
     "Hide" : "Ocultar",
+    "Disable" : "Deshabilitar",
+    "Unknown" : "Desconocido",
     "Never" : "Nunca",
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "La aplicación ha sido habilitada pero necesita ser actualizada. Serás redireccionado a la página de actualización en 5 segundos. ",
+    "Error" : "Error",
     "Forum" : "Foro",
     "Legal notice" : "Aviso legal",
     "SSL" : "SSL",
@@ -215,42 +217,24 @@ OC.L10N.register(
     "Credentials" : "Credenciales",
     "SMTP Password" : "Contraseña SMTP",
     "Save" : "Guardar",
+    "Security & setup warnings" : "Advertencias de seguridad y configuración",
     "All checks passed." : "Pasaron todas las verificaciones. ",
     "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Desarrollado por la  {communityopen}comunidad Nextcloud {linkclose}, el {githubopen}código fuente {linkclose} está licenciado bajo  {licenseopen}AGPL{linkclose}.",
     "Like our Facebook page" : "Da un Like a nuestra página de Facebook",
-    "Follow us on Twitter" : "Síguenos en Twitter",
     "Check out our blog" : "Visita nuestro blog",
     "Subscribe to our newsletter" : "Suscribete a nuestro boletín",
     "No user supplied" : "No se proporcionó usuario alguno",
     "Please provide an admin recovery password; otherwise, all user data will be lost." : "Por favor proporciona una contraseña de recuperación de administrador; de lo contrario toda la información del usuario se perderá. ",
-    "Federated Cloud Sharing" : "Compartir en la Nube Federada",
     "Invalid user" : "Usuario inválido",
     "Your username is: %s" : "Tu Usuario es: %s",
     "Logged in user must be a subadmin" : "El usuario firmado debe ser un subadministrador ",
-    "Enable all" : "Habilitar todo",
-    "Internet Explorer" : "Internet Explorer",
-    "Edge" : "Edge",
-    "Firefox" : "Firefox",
-    "Google Chrome" : "Google Chrome",
-    "Safari" : "Safari",
-    "Sync client - {os}" : "Sync client - {os}",
-    "Error while deleting the token" : "Se presentó un error al borrar la ficha",
-    "Use the credentials below to configure your app or device." : "Usa las siguientes credenciales para configurar tu aplicación o dispositivo. ",
-    "For security reasons this password will only be shown once." : "Por razones de seguridad esta contraseña sólo se mostrará una vez. ",
-    "Copied!" : "¡Copiado!",
-    "Copy" : "Copiar",
-    "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "Para correr esto necesitas la extensión POSIX de PHP. Por favor ve la {linkstart}documentación de PHP{linkend} para más detalles. ",
-    "Your email address" : "Tu dirección de correo electrónico",
-    "Your Twitter handle" : "Tu cuenta de Twitter",
-    "Add group" : "Agregar grupo",
-    "Active users" : "Usuarios activos",
-    "Show user backend" : "Mostrar backend del usuario",
-    "Send email to new user" : "Enviar un correo electrónico al usuario nuevo",
-    "Not saved" : "No guardado",
-    "Twitter" : "Twitter",
-    "SMTP Username" : "Usuario SMTP",
-    "Set default expiration date" : "Establecer la fecha de expiración predeterminada",
     "Exclude groups from sharing" : "Evitar que los grupos compartan",
-    "These groups will still be able to receive shares, but not to initiate them." : "Estos grupos aún podrán recibir elementos compartidos, pero no los podrán iniciar."
+    "These groups will still be able to receive shares, but not to initiate them." : "Estos grupos aún podrán recibir elementos compartidos, pero no los podrán iniciar.",
+    "Username" : "Usuario",
+    "User backend" : "Backend del usuario",
+    "Show user backend" : "Mostrar backend del usuario",
+    "Active users" : "Usuarios activos",
+    "SMTP Username" : "Usuario SMTP",
+    "Follow us on Twitter" : "Síguenos en Twitter"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
