@@ -72,6 +72,7 @@ OC.L10N.register(
     "Email could not be sent. Check your mail server log" : "No fue posible enviar el correo electrónico. Por favor verfica la bitácora de tu servidor de correo",
     "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Se presentó un problema al enviar el correo electrónico. Por favor revisa tus configuraciones (Error: %s)",
     "You need to set your account email before being able to send test emails. Go to %s for that." : "Necesita establecer su cuenta de correo electrónico antes de poder enviar correos de prueba. Vaya a %s para hacerlo.",
+    "Recently active" : "Activo recientemente",
     "Disabled accounts" : "Cuentas deshabilitadas",
     "Invalid account" : "Cuenta inválida",
     "Invalid mail address" : "Dirección de correo inválida",
@@ -120,10 +121,17 @@ OC.L10N.register(
     "Personal info" : "Información Personal",
     "Mobile & desktop" : "Móvil & escritorio",
     "Email server" : "Servidor de correo electrónico",
-    "Security & setup warnings" : "Advertencias de seguridad y configuración",
+    "Mail Providers" : "Proveedores de correo electrónico",
+    "Send emails using" : "Enviar correos electrónicos usando",
+    "User's email account" : "Cuenta de correo electrónico del usuario",
+    "System email account" : "Cuenta de correo electrónico del sistema",
+    "Security & setup checks" : "Revisiones de seguridad y configuración",
     "Background jobs" : "Trabajos en segundo plano",
     "Unlimited" : "Ilimitado",
     "Verifying" : "Verificando",
+    "Allowed admin IP ranges" : "Rangos de IP permitidos para administración",
+    "Admin IP filtering isn’t applied." : "El filtrado de IP de administración no está siendo aplicado.",
+    "Admin IP filtering is correctly configured." : "El filtro de IP de administración está configurado correctamente.",
     "App directories owner" : "Propietario de los directorios de aplicaciones",
     "Some app directories are owned by a different user than the web server one. This may be the case if apps have been installed manually. Check the permissions of the following app directories:\n%s" : "Algunos directorios de aplicaciones son propiedad de un usuario diferente al del servidor web. Esto puede ocurrir si las aplicaciones se han instalado manualmente. Compruebe los permisos de los siguientes directorios de aplicaciones:\n%s",
     "App directories have the correct owner \"%s\"" : "Los directorios de aplicaciones tienen al propietario correcto \"%s\"",
@@ -149,6 +157,8 @@ OC.L10N.register(
     "Missing optional column \"%s\" in table \"%s\"." : "Falta la columna opcional \"%s\" en la tabla \"%s\".",
     "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "A la base de datos le faltan algunas columnas opcionales. Debido al hecho de que añadir columnas en tablas grandes puede llevar cierto tiempo, no se han añadido automáticamente. Al ejecutar \"occ db:add-missing-columns\" se pueden añadir las columnas faltantes manualmente mientras la instancia sigue corriendo. Una vez se añadidas las columnas, algunas características podrían mejorar su capacidad de respuesta o la usabilidad.",
     "Database missing indices" : "Faltan índices en la base de datos",
+    "Missing indices:" : "Índices no encontrados:",
+    "\"%s\" in table \"%s\"" : "\"%s\" en tabla \"%s\"",
     "Database missing primary keys" : "Faltan llaves primarias en la base de datos",
     "Missing primary key on table \"%s\"." : "Falta la llave primaria en la tabla \"%s\".",
     "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "A la base de datos le faltan algunas llaves primarias. Debido al hecho de que añadir llaves primarias en tablas grandes puede llevar cierto tiempo, no se han añadido automáticamente. Al ejecutar \"occ db:add-missing-primary-keys\" se pueden añadir las llaves primarias faltantes manualmente mientras la instancia sigue corriendo. ",
@@ -157,14 +167,19 @@ OC.L10N.register(
     "This instance is running in debug mode. Only enable this for local development and not in production environments." : "Esta instancia se está ejecutando en modo de depuración. Habilite esto únicamente para desarrollo local y no en ambientes de producción.",
     "Debug mode is disabled." : "El modo de depuración está deshabilitado.",
     "Default phone region" : "Región predeterminada para teléfonos",
+    "Your installation has no default phone region set. This is required to validate phone numbers in the profile settings without a country code. To allow numbers without a country code, please add \"default_phone_region\" with the respective ISO 3166-1 code of the region to your config file." : "Tu instalación no tiene una región predeterminada para teléfonos seleccionada. Esto es necesario para validar números de teléfono en los ajustes de usuario que no tienen un código de país. Para permitir números sin código de país, añade en tu archivo de configuración el ajuste \"default_phone_region\" con el código regional ISO 3166-1 correspondiente.",
     "Email test" : "Correo de prueba",
     "Email test was successfully sent" : "Correo de prueba enviado correctamente",
-    "File locking" : "Bloqueo de archivos",
+    "You have not set or verified your email server configuration, yet. Please head over to the \"Basic settings\" in order to set them. Afterwards, use the \"Send email\" button below the form to verify your settings." : "No has introducido o verificado la configuración de tu servidor de correo todavía. Por favor, ve a \"Ajustes básicos\" para configurarlo. A continuación, usa el botón \"Enviar correo\" bajo el formulario para verificar tus ajustes.",
+    "Transactional File Locking" : "Bloqueo transaccional de archivos",
+    "Transactional File Locking is disabled. This is not a a supported configuraton. It may lead to difficult to isolate problems including file corruption. Please remove the `'filelocking.enabled' => false` configuration entry from your `config.php` to avoid these problems." : "El bloqueo transaccional de archivos está deshabilitado. Esta no es una configuración soportada. Podría causar problemas difíciles de aislar incluyendo la corrupción de archivos. Por favor, remueva la configuración 'filelocking.enabled' => false` de su archivo config.php para evitar estos problemas.",
     "The database is used for transactional file locking. To enhance performance, please configure memcache, if available." : "La base de datos está siendo utilizada para bloqueo de ficheros transaccionales. Para mejorar el rendimiento, por favor configure memcache, si está disponible.",
     "Forwarded for headers" : "Cabeceras Reenviado para",
     "Your \"trusted_proxies\" setting is not correctly set, it should be an array." : "La configuración de \"trusted_proxies\" es incorrecta, debería ser un arreglo.",
+    "Your \"trusted_proxies\" setting is not correctly set, it should be an array of IP addresses - optionally with range in CIDR notation." : "El ajuste \"trusted_proxies\" no está definido correctamente, debería ser un arreglo de direcciones IP - opcionalmente con rango en notación CIDR.",
     "The reverse proxy header configuration is incorrect. This is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud." : "La configuración de la cabecera del proxy inverso es incorrecta. Esto es un problema de seguridad y puede permitir a un atacante fingir una dirección IP como visible para Nextcloud.",
     "Your IP address was resolved as %s" : "Su dirección IP se resolvió como %s",
+    "The reverse proxy header configuration is incorrect, or you are accessing Nextcloud from a trusted proxy. If not, this is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud." : "La configuración de la cabecera del proxy inverso es incorrecta, o estás tratando de acceder a Nextcloud desde un proxy verificado. En caso contrario, esto es un problema de seguridad y podría permitir a un atacante falsear su dirección IP como visible para Nextcloud.",
     "HTTPS access and URLs" : "Acceso HTTPS y URLs",
     "Accessing site insecurely via HTTP." : "Accediendo al sitio de manera insegura vía HTTP.",
     "You are accessing your instance over a secure connection, and your instance is generating secure URLs." : "Está accediendo a su instancia mediante una conexión segura, y su instancia está generando URLs seguros.",
@@ -181,8 +196,8 @@ OC.L10N.register(
     "Memcache" : "Memcache",
     "No memory cache has been configured. To enhance performance, please configure a memcache, if available." : "No hay un caché en memoria configurado. Para mejorar el rendimiento, por favor configure memcache, si está disponible.",
     "Configured" : "Configurado",
-    "MySQL Unicode support" : "Soporte unicode de MySQL",
     "You are not using MySQL" : "No está usando MySQL",
+    "MySQL Unicode support" : "Soporte unicode de MySQL",
     "MySQL is used as database and does support 4-byte characters" : "MySQL se está utilizando como base de datos y soporta caracteres de 4 bytes",
     "OCS provider resolving" : "El proveedor OCS está resolviendo",
     "Could not check if your web server properly resolves the OCM and OCS provider URLs." : "No se pudo verificar si su servidor web resuelve apropiadamente los URLs de proveedor OCS y OCM.",
@@ -254,12 +269,11 @@ OC.L10N.register(
     "Could not check that your web server serves `.well-known` correctly. Please check manually." : "No se pudo revisar si su servidor web sirve correctamente `.well-known`. Por favor, revise manualmente.",
     "Your web server is not properly set up to resolve `.well-known` URLs, failed on:\n`%s`" : "Su servidor web no está configurado apropiadamente para resolver URLs `.well-known`, falló en:\n`%s`",
     "Your server is correctly configured to serve `.well-known` URLs." : "Su servidor está correctamente configurado para servir URLs `.well-known`.",
-    "WOFF2 file loading" : "Cargando archivo WOFF2",
-    "Could not check for WOFF2 loading support. Please check manually if your webserver serves `.woff2` files." : "No se pudo verificar el soporte de carga WOFF2. Por favor, verifique manualmente si su servidor web sirve archivos `.woff2`.",
     "Profile information" : "Información del perfil",
     "Profile picture, full name, email, phone number, address, website, Twitter, organisation, role, headline, biography, and whether your profile is enabled" : "Foto de perfil, nombre completo, correo electrónico, número de teléfono, dirección, sitio web, Twitter, organización, cargo, titular, biografía y si su perfil está habilitado",
     "Nextcloud settings" : "Configuración de Nextcloud",
     "Task:" : "Tarea:",
+    "Enable" : "Habilitar",
     "Machine translation" : "Traducción de máquina",
     "Machine translation can be implemented by different apps. Here you can define the precedence of the machine translation apps you have installed at the moment." : "La traducción automática puede estar implementada por diferentes aplicaciones. Aquí puede definir la prioridad de las aplicaciones de traducción automática que ha instalado al momento.",
     "Image generation" : "Generación de imágenes",
@@ -288,7 +302,6 @@ OC.L10N.register(
     "Groups allowed to share" : "Grupos permitidos para compartir",
     "Groups excluded from sharing" : "Grupos excluidos para compartir",
     "Not allowed groups will still be able to receive shares, but not to initiate them." : "Los grupos no permitidos aún podrán recibir recursos compartidos, pero no los podrán iniciar.",
-    "Set default expiration date for shares" : "Establecer fecha de caducidad predeterminada para compartidos",
     "Enforce expiration date" : "Forzar fecha de expiración",
     "Default expiration time of new shares in days" : "Fecha de caducidad predeterminada de recursos compartidos en días",
     "Expire shares after x days" : "Los recursos compartidos caducan tras x días",
@@ -321,7 +334,6 @@ OC.L10N.register(
     "Show details for {appName} app" : "Mostrar detalles para la aplicación {appName}",
     "Update to {update}" : "Actualizar a {update}",
     "Remove" : "Eliminar",
-    "Disable" : "Deshabilitar",
     "Featured" : "Destacado",
     "This app is supported via your current Nextcloud subscription." : "Esta aplicación está soportada con la suscripción actual de Nextcloud.",
     "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Las aplicaciones destacadas están desarrolladas por y dentro de la comunidad. Ofrecen una funcionalidad central y están listas para usarlas en producción.",
@@ -349,12 +361,20 @@ OC.L10N.register(
     "Next slide" : "Diapositiva siguiente",
     "Choose slide to display" : "Elegir diapositiva a mostrar",
     "{index} of {total}" : "{index} de {total}",
+    "Daemon" : "Demonio",
+    "Deploy Daemon" : "Demonio de Desplegue",
+    "Type" : "Tipo",
+    "Display Name" : "Nombre a desplegar",
+    "GPUs support" : "Soporte de GPUs",
+    "Compute device" : "Dispositivo de cómputo",
     "Description" : "Descripción",
     "Details" : "Detalles",
     "All" : "Todos",
     "Limit app usage to groups" : "Limitar el uso de aplicaciones a grupos",
     "No results" : "Sin resultados",
     "Update to {version}" : "Actualizar a {version}",
+    "Default Deploy daemon is not accessible" : "No se puede acceder al demonio de despliegue predeterminado",
+    "Delete data on remove" : "Eliminar datos al remover",
     "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Esta aplicación no cuenta con una versión mínima de Nextcloud asignada. Esto será un error en el futuro.",
     "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Esta aplicación no cuenta con una versión máxima de Nextcloud asignada. Esto será un error en el futuro.",
     "This app cannot be installed because the following dependencies are not fulfilled:" : "Esta aplicación no puede ser instalada porque las siguientes dependencias no están satisfechas:",
@@ -412,6 +432,7 @@ OC.L10N.register(
     "Copy login name" : "Copiar el nombre de usuario",
     "Could not copy app password. Please copy it manually." : "No se pudo copiar la contraseña de aplicación. Por favor, cópiela manualmente.",
     "Could not copy login name. Please copy it manually." : "No se pudo copiar el nombre de usuario. Por favor, cópielo manualmente.",
+    "For the server to work properly, it's important to configure background jobs correctly. Cron is the recommended setting. Please see the documentation for more information." : "Para que el servidor funcione correctamente, es importante configurar correctamente los trabajos en segundo plano. Cron es la configuración recomendada. Consulte la documentación para obtener más información.",
     "Last job execution ran {time}. Something seems wrong." : "La última ejecución del trabajo fue {time}. Algo parece estar mal. ",
     "Last job ran {relativeTime}." : "El último trabajo se ejecutó {relativeTime}.",
     "Background job did not run yet!" : "¡El trabajo en segundo plano no se ha ejecutado todavía!",
@@ -426,7 +447,6 @@ OC.L10N.register(
     "Unable to update background job mode" : "No se pudo actualizar el modo de trabajo en segundo plano",
     "Profile" : "Perfil",
     "Enable or disable profile by default for new accounts." : "Habilitar o deshabilitar el perfil por defecto para nuevos usuarios.",
-    "Enable" : "Habilitar",
     "Unable to update profile default setting" : "No se pudo actualizar la configuración predeterminada del perfil",
     "{app}'s declarative setting field: {name}" : "Campo de configuración declarativa de {app}: {name}",
     "Failed to save setting" : "No se pudo guardar la configuración",
@@ -468,10 +488,11 @@ OC.L10N.register(
     "Error cropping profile picture" : "Error al recortar la foto de perfil",
     "Error saving profile picture" : "Error al guardar la foto de perfil",
     "Error removing profile picture" : "Error al eliminar la foto de perfil",
-    "Your biography" : "Su biografía",
+    "Enter your date of birth" : "Ingresa tu fecha de nacimiento",
+    "Unable to update date of birth" : "No se pudo actualizar tu fecha de nacimiento",
     "You are a member of the following groups:" : "Usted es miembro de los siguientes grupos:",
-    "You are using <strong>{usage}</strong>" : "Está usando <strong>{usage}</strong>",
-    "You are using <strong>{usage}</strong> of <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)" : "Está usando <strong>{usage}</strong> de <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)",
+    "You are using {s}{usage}{/s}" : "Estás usando {s}{usage}{/s}",
+    "You are using {s}{usage}{/s} of {s}{totalSpace}{/s} ({s}{usageRelative}%{/s})" : "Estás usando {s}{usage}{/s} de {s}{totalSpace}{/s} ({s}{usageRelative}%{/s})",
     "Your full name" : "Su nombre completo",
     "Primary email for password reset and notifications" : "Correo electrónico principal para restablecer la contraseña y notificaciones",
     "Email options" : "Opciones de correo electrónico",
@@ -489,6 +510,9 @@ OC.L10N.register(
     "Unable to delete additional email address" : "No se pudo eliminar la dirección de correo electrónico adicional",
     "No email address set" : "No se ha establecido la dirección de correo electrónico",
     "Your handle" : "Su identificador",
+    "Day to use as the first day of week" : "Primer día de la semana",
+    "Derived from your locale ({weekDayName})" : "Deducido de tu locale ({weekDayName})",
+    "Unable to update first day of week" : "No se pudo modificar el primer día de la semana",
     "Your headline" : "Su titular",
     "Languages" : "Idiomas",
     "Help translate" : "Ayuda a traducir",
@@ -506,6 +530,10 @@ OC.L10N.register(
     "Unable to update profile enabled state" : "No se pudo actualizar el estado de habilitado del perfil",
     "The more restrictive setting of either visibility or scope is respected on your Profile. For example, if visibility is set to \"Show to everyone\" and scope is set to \"Private\", \"Private\" is respected." : "Se respeta la configuración más restrictiva de visibilidad o alcance en su perfil. Por ejemplo, si la visibilidad está configurada como \"Mostrar a todos\" y el alcance está configurado como \"Privado\", se respeta \"Privado\".",
     "Unable to update visibility of {displayId}" : "No se pudo actualizar la visibilidad de {displayId}",
+    "she/her" : "ella",
+    "he/him" : "él",
+    "they/them" : "elle",
+    "Your pronouns. E.g. ${pronounsExample}" : "Tus pronombres. Por ejemplo ${pronounsExample}",
     "Your role" : "Su cargo",
     "Your X (formerly Twitter) handle" : "Su X (anteriormente Twitter)",
     "Your website" : "Tu sitio web",
@@ -534,16 +562,26 @@ OC.L10N.register(
     "Password (required)" : "Contraseña (requerida)",
     "Email (required)" : "Correo electrónico (requerido)",
     "Email" : "Correo electrónico",
+    "Member of the following groups (required)" : "Miembro de los siguientes grupos (requerido)",
+    "Member of the following groups" : "Miembro de los siguientes grupos",
+    "Set account groups" : "Configurar grupos de la cuenta",
+    "Admin of the following groups" : "Administrador de los siguientes grupos",
+    "Set account as admin for …" : "Establecer cuenta como administrador de ...",
     "Quota" : "Cuota",
+    "Set account quota" : "Definir cuota de la cuenta",
     "Language" : "Idioma",
     "Set default language" : "Establecer el idioma predeterminado",
+    "Add new account" : "Añadir nueva cuenta",
     "Manager" : "Administrador",
     "Set line manager" : "Establecer el administrador",
+    "Account name will be autogenerated" : "El nombre de la cuenta se generará automáticamente",
+    "Account name (required)" : "Nombre de la cuenta (requerido)",
     "Total rows summary" : "Resumen de filas totales",
     "Scroll to load more rows" : "Desplazar para cargar más filas",
     "Avatar" : "Avatar",
     "Account name" : "Nombre de cuenta",
     "Group admin for" : "Administrador del grupo para",
+    "Account backend" : "Backend de cuenta",
     "Storage location" : "Úbicación del almacenamiento",
     "Last login" : "Último inicio de sesión",
     "Account actions" : "Acciones de la cuenta",
@@ -563,6 +601,7 @@ OC.L10N.register(
     "Disable account" : "Deshabilitar cuenta",
     "Enable account" : "Habilitar cuenta",
     "Resend welcome email" : "Reenviar correo de bienvenida",
+    "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "En caso de pérdida del dispositivo o salida de la organización, esto puede borrar de forma remota los datos de Nextcloud de todos los dispositivos asociados con {userid}. Solo funciona si los dispositivos están conectados a Internet.",
     "Remote wipe of devices" : "Limpieza remota de dispositivos",
     "Wipe {userid}'s devices" : "Limpiar los dispositivos de {userid}",
     "Wiped {userid}'s devices" : "Los dispositivos de {userid} fueron limpiados",
@@ -611,6 +650,8 @@ OC.L10N.register(
     "Loading categories" : "Cargando categorías",
     "Developer documentation ↗" : "Documentación del desarrollador ↗",
     "Version {version}, {license}-licensed" : "Versión {version}, licencia {license}",
+    "Version {version}" : "Versión {version}",
+    "All accounts" : "Todas las cuentas",
     "Admins" : "Administradores",
     "Account group: {group}" : "Grupo de cuentas: {group}",
     "Account management" : "Administración de cuentas",
@@ -624,17 +665,20 @@ OC.L10N.register(
     "Location" : "Ubicación",
     "Profile picture" : "Foto de perfil",
     "About" : "Acerca de",
+    "Date of birth" : "Fecha de nacimiento",
     "Full name" : "Nombre completo",
     "Additional email" : "Correo electrónico adicional",
+    "Fediverse (e.g. Mastodon)" : "Fediverse (por ejemplo, Mastodon)",
     "Headline" : "Titular",
     "Organisation" : "Organización",
     "Phone number" : "Número de teléfono",
+    "Pronouns" : "Pronombre",
     "Role" : "Cargo",
     "X (formerly Twitter)" : "X (anteriormente Twitter)",
-    "Fediverse (e.g. Mastodon)" : "Fediverse (por ejemplo, Mastodon)",
     "Website" : "Sitio web",
     "Profile visibility" : "Visibilidad del perfil",
     "Locale" : "Configuración regional",
+    "First day of week" : "Primer día de la semana",
     "Not available as this property is required for core functionality including file sharing and calendar invitations" : "No disponible, ya que esta propiedad es necesaria para la funcionalidad básica, incluyendo el compartir archivos y las invitaciones de calendario.",
     "Not available as federation has been disabled for your account, contact your system administration if you have any questions" : "No disponible, ya que la federación ha sido deshabilitada para su cuenta, contacte a su administrador del sistema si tiene alguna pregunta",
     "Not available as publishing account specific data to the lookup server is not allowed, contact your system administration if you have any questions" : "No disponible, ya que no se permite la publicación de datos específicos de usuario en el servidor de búsqueda, póngase en contacto con el administrador del sistema si tiene alguna duda",
@@ -649,16 +693,25 @@ OC.L10N.register(
     "Show to everyone" : "Mostrar a todos",
     "Show to logged in accounts only" : "Mostrar únicamente a usuarios conectados",
     "Hide" : "Ocultar",
+    "manual-install apps cannot be updated" : "Las aplicaciones instaladas manualmente no pueden ser actualizadas",
+    "{progress}% Deploying …" : "{progress}% Desplegando...",
+    "{progress}% Initializing …" : "{progress}% Inicializando...",
+    "Health checking" : "Revisión de salud del servidor",
+    "Deploy and Enable" : "Desplegar y activar",
     "Download and enable" : "Descargar y habilitar",
+    "Disable" : "Deshabilitar",
     "Allow untested app" : "Permitir aplicación no probada",
     "The app will be downloaded from the App Store" : "La aplicación será descargada de la tienda de aplicaciones",
+    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Esta app no está marcada como compatible con tu versión de Nextcloud. Si continúas podrás instalar la app, pero ten en cuenta que podría no funcionar según lo esperado.",
+    "Unknown" : "Desconocido",
     "Never" : "Nunca",
     "Could not register device: Network error" : "No se pudo registrar el dispositivo: Error de red",
     "Could not register device: Probably already registered" : "No se pudo registrar el dispositivo: Probablemente ya esté registrado",
     "Could not register device" : "No se pudo registrar el dispositivo",
     "An error occurred during the request. Unable to proceed." : "Ocurrió un error durante la solicitud. No se puede continuar.",
-    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "La aplicación ha sido habilitada pero necesita ser actualizada. Serás redireccionado a la página de actualización en 5 segundos. ",
+    "The app has been enabled but needs to be updated." : "Esta app ha sido habilitada pero requiere ser actualizada.",
     "Error: This app cannot be enabled because it makes the server unstable" : "Error: Esta aplicación no se puede habilitar porque genera inestabilidad en el servidor",
+    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "La aplicación ha sido habilitada pero necesita ser actualizada. Serás redireccionado a la página de actualización en 5 segundos. ",
     "Do you really want to wipe your data from this device?" : "¿Realmente desea limpiar sus datos de este dispositivo?",
     "Confirm wipe" : "Confirmar limpieza",
     "Could not delete the app token" : "No se pudo eliminar el token de aplicación",
@@ -671,11 +724,13 @@ OC.L10N.register(
     "Account documentation" : "Documentación de la cuenta",
     "Administration documentation" : "Documentación de administración",
     "Forum" : "Foro",
+    "Nextcloud help & privacy resources" : "Ayuda de Nextcloud y recursos de privacidad",
     "General documentation" : "Documentación general",
     "Legal notice" : "Aviso legal",
     "Privacy policy" : "Política de privacidad",
     "None/STARTTLS" : "Ninguno/STARTTLS",
     "SSL" : "SSL",
+    "Mail delivery is disabled by instance config \"%s\"." : "El envío de correo electrónico se encuentra deshabilitado por la configuración de la instancia \"%s\".",
     "Open documentation" : "Abrir documentación",
     "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Es importante preparar este servidor para poder enviar correos electrónicos, como para restablecer contraseñas y notificaciones. ",
     "Send mode" : "Modo de envío",
@@ -691,6 +746,8 @@ OC.L10N.register(
     "SMTP Password" : "Contraseña SMTP",
     "Save" : "Guardar",
     "Test and verify email settings" : "Probar y verificar la configuración del correo electrónico",
+    "Security & setup warnings" : "Advertencias de seguridad y configuración",
+    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Es importante para la seguridad y rendimiento de su instancia que todo esté correctamente configurado. Para ayudarle en ello estamos haciendo algunas comprobaciones automáticas. Para más información, por favor compruebe la documentación enlazada.",
     "All checks passed." : "Pasaron todas las verificaciones. ",
     "There are some errors regarding your setup." : "Hay algunos errores referentes a su configuración.",
     "There are some warnings regarding your setup." : "Hay algunas advertencias referentes a su configuración.",
@@ -700,7 +757,7 @@ OC.L10N.register(
     "Reasons to use Nextcloud in your organization" : "Razones para usar Nextcloud en su organización",
     "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Desarrollado por la  {communityopen}comunidad Nextcloud {linkclose}, el {githubopen}código fuente {linkclose} está licenciado bajo  {licenseopen}AGPL{linkclose}.",
     "Like our Facebook page" : "Da un Like a nuestra página de Facebook",
-    "Follow us on Twitter" : "Síguenos en Twitter",
+    "Follow us on X" : "Síguenos en X (ex Twitter)",
     "Follow us on Mastodon" : "Síguenos en Mastodon",
     "Check out our blog" : "Visita nuestro blog",
     "Subscribe to our newsletter" : "Suscribete a nuestro boletín",
@@ -717,6 +774,7 @@ OC.L10N.register(
     "A background job is pending that checks for user imported SSL certificates. Please check back later." : "Está pendiente una tarea en segundo plano que comprueba los certificados SSL de usuario importados. Por favor, vuelva a checar más tarde.",
     "Missing optional index \"%s\" in table \"%s\"." : "Falta el índice opcional \"%s\" en la tabla \"%s\".",
     "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "A la base de datos le faltan algunos índices. Debido al hecho de que añadir índices en tablas grandes puede llevar cierto tiempo, no se han añadido automáticamente. Al ejecutar \"occ db:add-missing-indices\" se pueden añadir los índices faltantes manualmente mientras la instancia sigue corriendo. Una vez se añadidos los índices, las consultas a esas tablas suelen ser mucho más rápidas.",
+    "File locking" : "Bloqueo de archivos",
     "Could not check for JavaScript support. Please check manually if your webserver serves `.mjs` files using the JavaScript MIME type." : "No se pudo checar el soporte para JavaScript. Por favor, revise manualmente si su servidor web sirve archivos `.mjs` utilizando el tipo JavaScript MIME.",
     "MySQL unicode support" : "Soporte unicode de MySQL",
     "Overwrite cli URL" : "Sobrescribir el URL de la línea de comandos",
@@ -729,6 +787,7 @@ OC.L10N.register(
     "None of your currently installed apps provide Text processing functionality" : "Ninguna de sus aplicaciones instaladas proveen la funcionalidad de procesamiento de texto",
     "Exclude groups from sharing" : "Evitar que los grupos compartan",
     "These groups will still be able to receive shares, but not to initiate them." : "Estos grupos aún podrán recibir elementos compartidos, pero no los podrán iniciar.",
+    "Set default expiration date for shares" : "Establecer fecha de caducidad predeterminada para compartidos",
     "Allow username autocompletion in share dialog and allow access to the system address book" : "Permitir autocompletado de nombres de usuario en el cuadro de diálogo de compartir y permitir acceso a la libreta de direcciones del sistema",
     "{license}-licensed" : "Licenciado bajo {license}",
     "Rating: {score}/10" : "Calificación: {score}/10",
@@ -738,6 +797,9 @@ OC.L10N.register(
     "The cron.php needs to be executed by the system user \"{user}\"." : "El cron.php debe ser ejecutado por el usuario del sistema \"{user}\".",
     "Enable or disable profile by default for new users." : "Habilitar o deshabilitar el perfil por defecto para nuevos usuarios.",
     "You are about to remove the group \"{group}\". The users will NOT be deleted." : "Está a punto de eliminar el grupo \"{group}\". Los usuarios NO serán eliminados.",
+    "Your biography" : "Su biografía",
+    "You are using <strong>{usage}</strong>" : "Está usando <strong>{usage}</strong>",
+    "You are using <strong>{usage}</strong> of <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)" : "Está usando <strong>{usage}</strong> de <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)",
     "Additional emails" : "Correos electrónicos adicionales",
     "Enable Profile" : "Habilitar perfil",
     "No users" : "Sin usuarios",
@@ -782,6 +844,7 @@ OC.L10N.register(
     "Show to logged in users only" : "Mostrar únicamente a usuarios conectados",
     "Nextcloud help resources" : "Recursos de ayuda de Nextcloud",
     "SMTP Username" : "Usuario SMTP",
+    "Follow us on Twitter" : "Síguenos en Twitter",
     "To allow this check to run you have to make sure that your webserver can connect to itself. Therefor it must be able to resolve and connect to at least one its `trusted_domains` or the `overwrite.cli.url`." : "Para permitir que esta verificación se lleve a cabo, debe asegurarse que su servidor web pueda conectarse a sí mismo. Por lo tanto, éste debe poder resolver y conectarse a al menos uno de sus `trusted_domains` o a `overwrite.cli.url`",
     "Active accounts" : "Cuentas activas"
 },
