@@ -8,21 +8,28 @@ OC.L10N.register(
     "Unable to change password" : "Nav iespējams nomainīt paroli",
     "Very weak password" : "Ļoti vāja parole",
     "Weak password" : "Vāja parole",
-    "So-so password" : "Normāla parole",
+    "So-so password" : "Viduvēja parole",
     "Good password" : "Laba parole",
-    "Strong password" : "Lieliska parole",
+    "Strong password" : "Spēcīga parole",
     "Groups" : "Grupas",
     "Group list is empty" : "Grupu saraksts ir tukšš",
     "Unable to retrieve the group list" : "Nevarēja saņemt grupu sarakstu",
-    "You successfully logged in using two-factor authentication (%1$s)" : "Esat veiksmīgi pieteicies, izmantojot divpakāpju autentifikācija (%1$s)",
-    "A login attempt using two-factor authentication failed (%1$s)" : "Pieteikšanās mēģinājums, izmantojot divpakāpju autentifikāciju neizdevās (%1$s)",
+    "{actor} changed your password" : "{actor] nomainīja Tavu paroli",
+    "You changed your password" : "Tu nomainīji savu paroli",
+    "You renamed app password \"{token}\" to \"{newToken}\"" : "Tu pārdēvēji lietotnes paroli \"{token}\" uz \"{newToken}\"",
+    "Security" : "Drošība",
+    "You successfully logged in using two-factor authentication (%1$s)" : "Veiksmīga pieteikšanās ar divpakāpju autentifikāciju (%1$s)",
+    "A login attempt using two-factor authentication failed (%1$s)" : "Pieteikšanās mēģinājums ar divpakāpju autentifikāciju neizdevās (%1$s)",
     "Settings" : "Iestatījumi",
+    "Could not update app." : "Lietotni nevarēja atjaunināt.",
     "Wrong password" : "Nepareiza parole",
     "Saved" : "Saglabāts",
     "Authentication error" : "Autentifikācijas kļūda",
-    "Wrong admin recovery password. Please check the password and try again." : "Nepareiza administratora atjaunošanas parole. Lūdzu pārbaudiet paroli un mēģiniet vēlreiz.",
-    "Administrator documentation" : "Administratora dokumentācija",
+    "Wrong admin recovery password. Please check the password and try again." : "Nepareiza pārvaldītāja atkopes parole. Lūgums pārbaudītt paroli un mēģināt vēlreiz.",
+    "Administrator documentation" : "Pārvaldītāja dokumentācija",
     "User documentation" : "Lietotāja dokumentācija",
+    "Nextcloud help overview" : "Nextcloud palīdzības pārskats",
+    "Invalid SMTP password." : "Nederīga SMTP parole",
     "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Radās kļūda, nosūtot e-pastu. Lūdzu, pārskatiet savus iestatījumus. (Kļūda: %s)",
     "Invalid account" : "Nederīgs konts",
     "Invalid mail address" : "Nepareiza e-pasta adrese",
@@ -32,22 +39,27 @@ OC.L10N.register(
     "Your %s account was created" : "Konts %s ir izveidots",
     "Apps" : "Lietotnes",
     "Personal" : "Personīgs",
-    "Administration" : "Administrēšana",
+    "Administration" : "Pārvaldīšana",
     "Users" : "Lietotāji",
     "Additional settings" : "Papildu iestatījumi",
-    "Administration privileges" : "Administrēšanas privilēģijas",
+    "Administration privileges" : "Pārvaldīšanas tiesības",
+    "Overview" : "Pārskats",
+    "Basic settings" : "Pamata iestatījumi",
     "Sharing" : "Koplietošana",
     "Availability" : "Pieejamība",
     "Calendar" : "Kalendārs",
     "Personal info" : "Personiskā informācija",
+    "Mobile & desktop" : "Tālrunis un darbvirsma",
     "Email server" : "E-pasta serveris",
-    "Security & setup warnings" : "Drošības un iestatījumu brīdinājumi",
     "Unlimited" : "Neierobežota",
+    "Could not check that the data directory is protected. Please check manually that your server does not allow access to the data directory." : "Nevarēja pārbaudīt, vai datu mape ir aizsargāta. Lūgums pašrocīgi pārbaudīt, ka serveris neļauj piekļūt datu mapei.",
+    "You have not set or verified your email server configuration, yet. Please head over to the \"Basic settings\" in order to set them. Afterwards, use the \"Send email\" button below the form to verify your settings." : "Vēl nav iestatīts e-pasta serveris vai apliecināta tā konfigurācija. Lūgums doties uz \"Pamata iestatījumi\", lai varētu to iestatīt. Pēc tam jāizmanto veidlapas apakšā esošā poga\"Nosūtīt e-pasta ziņojumu\", lai apliecinātu savus iestatījumus.",
     "Disabled" : "Atspējots",
     "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP nešķiet pareizi uzstādīts lai veiktu sistēmas vides mainīgo vaicājumus. Tests ar getenv(\"PATH\") atgriež tikai tukšu atbildi.",
     "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Ir iespējots tikai lasāma konfigurācija. Tas neatļauj iestatīt un mainīt dažas konfigurācijas caur tīmekļa interfeisu. Šī datne būs manuāli jāpārveido par rakstāmu, pirms katra atjauninājuma instalēšanas.",
-    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Jūsu datubāze neiet ar \"READ COMMITED\" transakciju izolācijas līmeni. Tas var radīt problēmas kad vairākas darbības tiek veiktas pararēli.",
+    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Datubāze nedarbojas ar \"READ COMMITED\" transakciju izolācijas līmeni. Tas var radīt sarežģījumus, kad vienlaicīgi tiek veiktas vairākas darbības.",
     "Nextcloud settings" : "Nextcloud iestatījumi",
+    "Enable" : "Aktivēt",
     "None" : "Nav",
     "Allow apps to use the Share API" : "Ļaut programmām izmantot koplietošanas API",
     "Allow resharing" : "Atļaut atkārtotu koplietošanu",
@@ -55,28 +67,36 @@ OC.L10N.register(
     "Restrict users to only share with users in their groups" : "Ierobežot lietotājiem koplietot tikai ar lietotājiem savās grupās",
     "Allow public uploads" : "Atļaut publisko augšupielādi",
     "Enforce password protection" : "Ieviest paroles aizsardzību",
-    "Enforce expiration date" : "Uzspiest beigu termiņu",
-    "Limit to groups" : "Grupu ierobežojums",
+    "Enforce expiration date" : "Uzspiest beigu datumu",
+    "Privacy settings for sharing" : "Kopīgošanas privātuma iestatījumi",
+    "Limit to groups" : "Ierobežot kopām",
     "Save changes" : "Saglabāt izmaiņas",
+    "Update to {update}" : "Atjaunināt uz {update}",
     "Remove" : "Izņemt",
-    "Disable" : "Deaktivēt",
     "Icon" : "Ikona",
-    "Name" : "Vārds",
+    "Name" : "Nosaukums",
     "Version" : "Versija",
+    "Level" : "Līmenis",
     "Actions" : "Darbības",
     "No apps found for your version" : "Neatrada lietotnes jūsu versijai",
+    "_%n app has an update available_::_%n apps have an update available_" : ["%n lietotnēm ir pieejams atjauninājums","%n lietotnei ir pieejams atjauninājums","%n lietotnēm ir pieejams atjauninājums"],
+    "_Update_::_Update all_" : ["Atjaunināt visas","Atjaunināt","Atjaunināt visas"],
+    "Loading" : "Ielādē",
+    "Type" : "Veids",
+    "Display Name" : "Attēlojamais vārds",
     "Description" : "Apraksts",
     "Details" : "Detaļas",
     "All" : "Visi",
     "No results" : "Nav rezultātu",
-    "Update to {version}" : "Atjaunināts uz {version}",
+    "Update to {version}" : "Atjaunināt uz {version}",
+    "Latest updated" : "Pēdējoreiz atjaunināta",
     "Categories" : "Kategorijas",
     "Resources" : "Resursi",
     "Documentation" : "Dokumentācija",
     "Report a bug" : "Ziņot par kļūdu",
     "Rate" : "Vērtēt",
     "Visit website" : "Apmeklējiet vietni",
-    "Admin documentation" : "Administratora dokumentācija",
+    "Admin documentation" : "Pārvaldītāja dokumentācija",
     "Developer documentation" : "Izstrādātāja dokumentācija",
     "Changelog" : "Izmaiņu žurnāls",
     "Device settings" : "Ierīces iestatījumi",
@@ -86,18 +106,21 @@ OC.L10N.register(
     "This session" : "Šajā sesijā",
     "Device" : "Ierīce",
     "Last activity" : "Pēdējās darbības",
+    "Devices & sessions" : "Ierīces un sesijas",
     "App name" : "Lietotnes nosaukums",
     "Create new app password" : "Izveidot jaunu lietotnes paroli",
+    "New app password" : "Jauna lietotnes parole",
+    "Use the credentials below to configure your app or device. For security reasons this password will only be shown once." : "Zemāk esošie piekļuves dati jāizmanto, lai konfigurētu lietotni vai ierīci. Drošības iemeslu dēļ šī parole tiks parādīta tikai vienu reizi.",
     "Login" : "Autorizēties",
     "Password" : "Parole",
+    "Show QR code for mobile apps" : "Parādīt kvadrātkodu tālruņa lietotnēm",
     "Profile" : "Profils",
-    "Enable" : "Aktivēt",
     "Server-side encryption" : "Servera šifrēšana",
     "Enable server-side encryption" : "Ieslēgt servera šifrēšanu",
     "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "Šifrēšana vien negarantē sistēmas drošību. Skatiet dokumentāciju, lai iegūtu papildinformāciju par šifrēšanas lietotnes izmantošanu un atbalstītajiem izmantošanas veidiem.",
     "Be aware that encryption always increases the file size." : "Jāapzinās, ka šifrēšanas vienmēr palielina datnes lielumu.",
-    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Vienmēr ir ieteicams regulāri veidot dublējumkopijas datu šifrēšanas gadījumam, pārliecinieties, lai dublētu, šifrēšanas atslēgas ir kopā ar jūsu datiem.",
-    "This is the final warning: Do you really want to enable encryption?" : "Šis ir pēdējais brīdinājums: vai tiešām vēlaties iespējot šifrēšanu?",
+    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Vienmēr ir ieteicams regulāri veidot datu rezerves kopijas, un šifrēšanas gadījumā jāpārliecinās, ka līdz ar datiem rezerves kopijas ir izveidotas arī šifrēšanas atslēgām.",
+    "This is the final warning: Do you really want to enable encryption?" : "Šis ir pēdējais brīdinājums: vai tiešām iespējot šifrēšanu?",
     "No encryption module loaded, please enable an encryption module in the app menu." : "Nav ielādēts šifrēšanas moduļis, lūdzu, aktivizējiet šifrēšanas moduli lietotņu izvēlnē.",
     "Select default encryption module:" : "Atlasiet noklusēto šifrēšanas moduli:",
     "Cancel" : "Atcelt",
@@ -107,47 +130,72 @@ OC.L10N.register(
     "Current password" : "Pašreizējā parole",
     "New password" : "Jauna parole",
     "Change password" : "Mainīt paroli",
+    "The file must be a PNG or JPG" : "Failam jābūt PNG vai JPG",
+    "Enter your date of birth" : "Ievadiet Jūsu dzimšanas datumu",
+    "Unable to update date of birth" : "Nevarēja atjaunināt dzimšanas datumu",
+    "You are a member of the following groups:" : "Jūs esat lietotājs sekojošās grupās:",
+    "You are using {s}{usage}{/s}" : "Jūs izmantojat {s}{usage}{/s}",
+    "You are using {s}{usage}{/s} of {s}{totalSpace}{/s} ({s}{usageRelative}%{/s})" : "Jūs izmantojat {s}{usage}{/s} no {s}{totalSpace}{/s} ({s}{usageRelative}%{/s})",
+    "Primary email for password reset and notifications" : "Primārā e-pasta adrese paroles atjaunošanai un paziņojumiem",
     "No email address set" : "Nav norādīts e-pasts",
     "Help translate" : "Palīdzi tulkot",
+    "Locales" : "Lokalizācijas",
+    "Week starts on {firstDayOfWeek}" : "Nedēļa sākas {firstDayOfWeek}",
+    "Unable to update locale" : "Nevarēja atjaunināt lokalizāciju",
+    "No locale set" : "Lokalizācija nav iestatīta",
     "Your phone number" : "Jūsu tālruņa numurs",
+    "Edit your Profile visibility" : "Labot Jūsu profila redzamību",
+    "Your role" : "Jūsu loma",
     "Your website" : "Jūsu mājaslapa",
     "Add" : "Pievienot",
     "Create" : "Izveidot",
     "Change" : "Mainīt",
     "Delete" : "Dzēst",
-    "Display name" : "Ekrāna vārds",
+    "Display name" : "Attēlojamais vārds",
     "Email" : "E-pasts",
     "Quota" : "Apjoms",
     "Language" : "Valoda",
+    "Scroll to load more rows" : "Ritināt, lai ielādētu vairāk rindu",
     "Avatar" : "Profila attēls",
-    "Username" : "Lietotājvārds",
-    "Group admin for" : "Admin grupa",
+    "Account name" : "Konta nosaukums",
+    "Group admin for" : "Kopa \"pārvaldītājs\"",
     "Storage location" : "Krātuves atrašanās vieta",
     "Last login" : "Pēdējā pieteikšanās",
+    "Account actions" : "Konta darbības",
     "Delete account" : "Dzēst kontu",
     "Done" : "Pabeigts",
-    "Edit" : "Rediģēt",
+    "Edit" : "Labot",
     "Visibility" : "Redzamība",
     "Show last login" : "Rādīt pēdējo autorizāciju",
     "Send email" : "Sūtīt e-pastu",
     "Default quota" : "Apjoms pēc noklusējuma",
-    "Admins" : "Admins",
+    "Admins" : "Pārvaldītāji",
     "Group name" : "Grupas nosaukums",
     "Sending…" : "Sūta …",
     "Email sent" : "Vēstule nosūtīta",
-    "Location" : "Vieta",
+    "Location" : "Atrašanās vieta",
     "Profile picture" : "Profila attēls",
     "About" : "Par",
+    "Date of birth" : "Dzimšanas datums",
     "Full name" : "Pilns vārds",
     "Phone number" : "Tālruņa numurs",
+    "Role" : "Loma",
     "Website" : "Mājaslapa",
+    "Locale" : "Lokalizācija",
+    "First day of week" : "Pirmā nedēļas diena",
     "Updates" : "Atjauninājumi",
     "Hide" : "Slēpt",
+    "Disable" : "Deaktivēt",
+    "Unknown" : "Nezināms",
     "Never" : "Nekad",
+    "Do you really want to wipe your data from this device?" : "Vai tiešām izdzēst datus šajā ierīcē?",
+    "Error" : "Kļūda",
     "Forum" : "Forums",
+    "Nextcloud help & privacy resources" : "Nextcloud palīdzība un privātuma līdzekļi",
     "Privacy policy" : "Privātuma politika",
     "SSL" : "SSL",
     "Open documentation" : "Atvērt dokumentāciju",
+    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Ir svarīgi iestatīt šo serveri, lai varētu nosūtīt e-pasta ziņojumus, piemēram, paroles atiestatīšanai un paziņojumus.",
     "Send mode" : "Sūtīšanas metode",
     "Encryption" : "Šifrēšana",
     "From address" : "No adreses",
@@ -158,30 +206,17 @@ OC.L10N.register(
     "Credentials" : "Akreditācijas dati",
     "SMTP Password" : "SMTP parole",
     "Save" : "Saglabāt",
+    "Security & setup warnings" : "Drošības un iestatījumu brīdinājumi",
     "All checks passed." : "Visas pārbaudes veiksmīgas.",
     "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Izstrādātās {communityopen}Nextcloud kopiena {linkclose},  {githubopen} avota kods {linkclose} licencēts saskaņā ar {licenseopen}AGPL{linkclose}.",
     "No user supplied" : "Nav norādīts lietotājs",
-    "Federated Cloud Sharing" : "Federatīva mākoņkoplietošana",
     "Invalid user" : "Nepareizs lietotājs",
-    "Internet Explorer" : "Internet Explorer",
-    "Edge" : "Edge",
-    "Firefox" : "Firefox",
-    "Google Chrome" : "Google Chrome",
-    "Safari" : "Safari",
-    "iPhone" : "iPhone",
-    "Sync client - {os}" : "Sync klients - {os}",
-    "Use the credentials below to configure your app or device." : "Izmantot akreditācijas datus, lai konfigurētu savu lietotni vai ierīci.",
-    "For security reasons this password will only be shown once." : "Drošības apsvērumu dēļ šī parole, tiks parādīta tikai vienreiz.",
-    "Copied!" : "Nokopēts!",
-    "Copy" : "Kopēt",
-    "Your email address" : "Jūsu e-pasta adrese",
-    "Add group" : "Pievienot grupu",
+    "Exclude groups from sharing" : "Izslēgt grupas no koplietošanas",
+    "Username" : "Lietotājvārds",
+    "Your biography" : "Jūsu biogrāfija",
+    "You are using <strong>{usage}</strong>" : "Jūs izmantojat <strong>{usage}</strong>",
+    "You are using <strong>{usage}</strong> of <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)" : "Jūs izmantojat <strong>{usage}</strong> no <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)",
     "Active users" : "Aktīvie lietotāji",
-    "Send email to new user" : "Sūtīt e-pastu jaunajam lietotājam",
-    "Not saved" : "Nav saglabāts",
-    "Twitter" : "Twitter",
-    "SMTP Username" : "SMTP lietotājvārds",
-    "Set default expiration date" : "Iestatīt noklusējuma beigu datumu",
-    "Exclude groups from sharing" : "Izslēgt grupas no koplietošanas"
+    "SMTP Username" : "SMTP lietotājvārds"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
