@@ -112,7 +112,6 @@ OC.L10N.register(
     "Personal info" : "Thông tin cá nhân",
     "Mobile & desktop" : "Điện thoại di động và máy tính để bàn",
     "Email server" : "Máy chủ mail",
-    "Security & setup warnings" : "Bảo mật và thiết lập cảnh báo",
     "Background jobs" : "Các công việc trong nền",
     "Unlimited" : "Không giới hạn",
     "Verifying" : "Đang xác minh",
@@ -140,6 +139,7 @@ OC.L10N.register(
     "Profile picture, full name, email, phone number, address, website, Twitter, organisation, role, headline, biography, and whether your profile is enabled" : "Ảnh hồ sơ, tên đầy đủ, email, số điện thoại, địa chỉ, trang web, Twitter, tổ chức, vai trò, tiêu đề, tiểu sử và liệu hồ sơ của bạn có được bật hay không",
     "Nextcloud settings" : "Cài đặt Cloud",
     "Task:" : "Tác vụ:",
+    "Enable" : "Bật",
     "Machine translation" : "Dịch máy",
     "Machine translation can be implemented by different apps. Here you can define the precedence of the machine translation apps you have installed at the moment." : "Dịch máy có thể được thực hiện bởi các ứng dụng khác nhau. Tại đây, bạn có thể xác định mức độ ưu tiên của ứng dụng dịch máy mà bạn đã cài đặt vào lúc này.",
     "Image generation" : "Tạo hình ảnh",
@@ -158,7 +158,6 @@ OC.L10N.register(
     "Allow public uploads" : "Cho phép upload công cộng",
     "Always ask for a password" : "Luôn yêu cầu mật khẩu",
     "Enforce password protection" : "Thực thi bảo vệ mật khẩu",
-    "Set default expiration date for shares" : "Đặt ngày hết hạn mặc định cho cổ phiếu",
     "Enforce expiration date" : "Buộc có ngày hết hạn",
     "Set default expiration date for shares to other servers" : "Đặt ngày hết hạn mặc định cho việc chia sẻ sang các máy chủ khác",
     "If autocompletion \"same group\" and \"phone number integration\" are enabled a match in either is enough to show the user." : "Nếu tính năng tự động hoàn thành \"cùng nhóm\" và \"tích hợp số điện thoại\" được bật thì kết quả khớp trong cả hai đều đủ để hiển thị cho người dùng.",
@@ -177,7 +176,6 @@ OC.L10N.register(
     "Save changes" : "Lưu thay đổi",
     "Update to {update}" : "Cập nhật tới {update}",
     "Remove" : "Xóa",
-    "Disable" : "Tắt",
     "Featured" : "Tính năng được trang bị",
     "This app is supported via your current Nextcloud subscription." : "Ứng dụng này được hỗ trợ thông qua thuê bao Nextcloud hiện tại của bạn.",
     "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Các ứng dụng nổi bật được phát triển bởi và trong cộng đồng. Chúng cung cấp chức năng trung tâm và sẵn sàng để sử dụng trong sản xuất.",
@@ -194,6 +192,7 @@ OC.L10N.register(
     "_%n app has an update available_::_%n apps have an update available_" : ["%n ứng dụng có sẵn bản cập nhật"],
     "_Update_::_Update all_" : ["Cập nhật tất cả"],
     "Loading" : "Đang tải",
+    "Type" : "Loại",
     "Description" : "Mô tả",
     "Details" : "Thông tin",
     "All" : "Tất cả",
@@ -247,7 +246,6 @@ OC.L10N.register(
     "The PHP POSIX extension is required. See {linkstart}PHP documentation{linkend} for more details." : "Cần có phần mở rộng PHP POSIX. Xem {linkstart}tài liệu PHP{linkend} để biết thêm chi tiết.",
     "Unable to update background job mode" : "Không thể cập nhật chế độ công việc nền",
     "Profile" : "Hồ sơ",
-    "Enable" : "Bật",
     "Unable to update profile default setting" : "Không thể cập nhật cài đặt mặc định của hồ sơ",
     "Server-side encryption" : "Mã hoá phía máy chủ",
     "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "Mã hóa phía máy chủ giúp mã hóa các tệp được tải lên máy chủ này. Điều này đi kèm với những hạn chế như hình phạt về hiệu suất, vì vậy chỉ kích hoạt tính năng này nếu cần.",
@@ -286,10 +284,7 @@ OC.L10N.register(
     "Error cropping profile picture" : "Lỗi cắt ảnh hồ sơ",
     "Error saving profile picture" : "Lỗi lưu ảnh hồ sơ",
     "Error removing profile picture" : "Lỗi xóa ảnh hồ sơ",
-    "Your biography" : "Tiểu sử của bạn",
     "You are a member of the following groups:" : "Bạn là thành viên của các nhóm sau:",
-    "You are using <strong>{usage}</strong>" : "Bạn đang sử dụng {usage}",
-    "You are using <strong>{usage}</strong> of <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)" : "Bạn đang sử dụng {usage} trên {totalSpace} ({usageRelative}%)",
     "Your full name" : "Tên đầy đủ của bạn",
     "Primary email for password reset and notifications" : "Email chính để đặt lại mật khẩu và thông báo",
     "Email options" : "Tùy chọn email",
@@ -348,6 +343,7 @@ OC.L10N.register(
     "Total rows summary" : "Tóm tắt tổng số hàng",
     "Scroll to load more rows" : "Cuộn để tải thêm hàng",
     "Avatar" : "Hình đại diện",
+    "Account name" : "Tên tài khoản",
     "Group admin for" : "Quản trị viên nhóm",
     "Storage location" : "Khu vực lưu trữ",
     "Last login" : "Lần đăng nhập cuối",
@@ -424,13 +420,15 @@ OC.L10N.register(
     "Show to everyone" : "Hiển thị cho mọi người",
     "Hide" : "Ẩn",
     "Download and enable" : "Tải xuống và kích hoạt",
+    "Disable" : "Tắt",
     "Allow untested app" : "Cho phép ứng dụng chưa được kiểm tra",
     "The app will be downloaded from the App Store" : "Ứng dụng sẽ được tải xuống từ App Store",
     "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Ứng dụng này không được đánh dấu là tương thích với phiên bản Nextcloud của bạn. Nếu bạn tiếp tục, bạn vẫn có thể cài đặt ứng dụng. Lưu ý rằng ứng dụng có thể không hoạt động như mong đợi.",
+    "Unknown" : "Không xác định",
     "Never" : "Không bao giờ",
     "An error occurred during the request. Unable to proceed." : "Đã xảy ra lỗi trong quá trình yêu cầu. Không thể tiếp tục.",
-    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Ứng dụng đã được kích hoạt nhưng cần được cập nhật. Bạn sẽ được chuyển hướng đến trang cập nhật sau 5 giây.",
     "Error: This app cannot be enabled because it makes the server unstable" : "Lỗi: Không thể kích hoạt ứng dụng này vì nó khiến máy chủ không ổn định",
+    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Ứng dụng đã được kích hoạt nhưng cần được cập nhật. Bạn sẽ được chuyển hướng đến trang cập nhật sau 5 giây.",
     "Do you really want to wipe your data from this device?" : "Bạn có thực sự muốn xóa dữ liệu của bạn khỏi thiết bị này?",
     "Confirm wipe" : "Xác nhận xóa",
     "Error while wiping the device with the token" : "Lỗi trong khi xóa thiết bị bằng mã thông báo",
@@ -458,6 +456,7 @@ OC.L10N.register(
     "SMTP Password" : "Mật khẩu SMTP",
     "Save" : "Lưu",
     "Test and verify email settings" : "Kiểm tra và xác minh cài đặt email",
+    "Security & setup warnings" : "Bảo mật và thiết lập cảnh báo",
     "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Điều quan trọng đối với tính bảo mật và hiệu suất của phiên bản của bạn là mọi thứ đều được đặt cấu hình chính xác. Để giúp bạn điều đó, chúng tôi đang thực hiện một số kiểm tra tự động. Vui lòng xem tài liệu được liên kết để biết thêm thông tin.",
     "All checks passed." : "Tất cả các kiểm tra đã thoả điều kiện",
     "There are some errors regarding your setup." : "Có một số lỗi liên quan đến thiết lập của bạn.",
@@ -484,6 +483,7 @@ OC.L10N.register(
     "None of your currently installed apps provide Text processing functionality" : "Không có ứng dụng nào bạn cài đặt hiện tại cung cấp chức năng xử lý văn bản",
     "Exclude groups from sharing" : "Loại trừ các nhóm khỏi việc chia sẻ",
     "These groups will still be able to receive shares, but not to initiate them." : "Các nhóm này vẫn có thể nhận được lượt chia sẻ nhưng không thể bắt đầu chia sẻ.",
+    "Set default expiration date for shares" : "Đặt ngày hết hạn mặc định cho cổ phiếu",
     "Allow username autocompletion in share dialog and allow access to the system address book" : "Cho phép tự động hoàn thành tên người dùng trong hộp thoại chia sẻ và cho phép truy cập vào sổ địa chỉ hệ thống",
     "Two-factor authentication can be enforced for all users and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "Xác thực hai yếu tố có thể được thực thi cho tất cả người dùng và các nhóm cụ thể. Nếu họ không cấu hình nhà cung cấp hai yếu tố, họ sẽ không thể đăng nhập vào hệ thống.",
     "When groups are selected/excluded, they use the following logic to determine if a user has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If a user is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "Khi các nhóm được chọn / loại trừ, họ sử dụng logic sau để xác định xem người dùng có thực thi 2FA hay không: Nếu không có nhóm nào được chọn, 2FA được bật cho mọi người trừ các thành viên của các nhóm bị loại trừ. Nếu các nhóm được chọn, 2FA được bật cho tất cả các thành viên trong số này. Nếu người dùng ở cả hai nhóm được chọn và bị loại trừ, quyền được chọn sẽ được ưu tiên và 2FA được thi hành.",
@@ -494,6 +494,9 @@ OC.L10N.register(
     "The cron.php needs to be executed by the system user \"{user}\"." : "Cron.php cần được thực thi bởi người dùng hệ thống \"{user}\".",
     "Enable or disable profile by default for new users." : "Bật hoặc tắt hồ sơ theo mặc định cho người dùng mới.",
     "You are about to remove the group \"{group}\". The users will NOT be deleted." : "Bạn sắp xóa nhóm \"{group}\". Người dùng sẽ KHÔNG bị xóa.",
+    "Your biography" : "Tiểu sử của bạn",
+    "You are using <strong>{usage}</strong>" : "Bạn đang sử dụng {usage}",
+    "You are using <strong>{usage}</strong> of <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)" : "Bạn đang sử dụng {usage} trên {totalSpace} ({usageRelative}%)",
     "Additional emails" : "Email bổ sung",
     "Enable Profile" : "Bật hồ sơ",
     "No users" : "Không có người dùng",
@@ -527,7 +530,7 @@ OC.L10N.register(
     "Send welcome email to new users" : "Gửi email chào mừng tới người dùng mới",
     "Name your device" : "Đặt tên cho thiết bị của bạn",
     "Server error while trying to add WebAuthn device" : "Lỗi máy chủ khi cố gắng thêm thiết bị WebAuthn",
-    "by {author}\n{license}" : "bởi {tác giả}{giấy phép}",
+    "by {author}\n{license}" : "bởi {author}\n{license}",
     "Active users" : "Người dùng hoạt động",
     "Disabled users" : "Người dùng đã bị vô hiệu hóa",
     "Creating group …" : "Đang tạo nhóm…",
