@@ -52,17 +52,16 @@ OC.L10N.register(
     "Privacy policy" : "Política de privadesa",
     "Adjust the Nextcloud theme" : "Ajusteu el tema del Nextcloud",
     "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Els temes us permeten personalitzar fàcilment l'aspecte de la instància i dels clients compatibles. Serà visible per a tots els usuaris.",
+    "Upload new logo" : "Puja un logotip nou",
+    "Logo" : "Logotip",
+    "Upload new background and login image" : "Puja una imatge de fons i inici de sessió nova",
+    "Background and login image" : "Imatge de fons i d'inici de sessió",
     "Advanced options" : "Paràmetres avançats",
     "Install the ImageMagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Instal·leu l'extensió del PHP d'ImageMagick compatible amb imatges SVG per a generar automàticament icones de web a partir del logotip i del color pujats.",
     "Name" : "Nom",
     "Web link" : "Enllaç web",
     "a safe home for all your data" : "Un lloc segur per a totes les vostres dades",
     "Slogan" : "Eslògan",
-    "Color" : "Color",
-    "Logo" : "Logotip",
-    "Upload new logo" : "Puja un logotip nou",
-    "Background and login image" : "Imatge de fons i d'inici de sessió",
-    "Upload new background and login image" : "Puja una imatge de fons i inici de sessió nova",
     "Legal notice link" : "Enllaç a l'avís legal",
     "Privacy policy link" : "Enllaç a la política de privadesa",
     "Header logo" : "Logotip de capçalera",
@@ -73,9 +72,8 @@ OC.L10N.register(
     "Disable user theming" : "Inhabilita els temes d'usuari",
     "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can toggle this on." : "Tot i que podeu seleccionar i personalitzar la instància, els usuaris poden canviar el fons i els colors. Si voleu forçar la vostra personalització, podeu activar-ho.",
     "Appearance and accessibility settings" : "Paràmetres d'aparença i accessibilitat",
-    "Background and color" : "Fons i color",
     "Customization has been disabled by your administrator" : "L'administrador ha inhabilitat la personalització",
-    "The background can be set to an image from the default set, a custom uploaded image, or a plain color. The primary color will automatically be adapted based on this and used for elements like folder icons, primary buttons and highlights." : "Podeu establir el fons en una imatge del conjunt per defecte, una imatge personalitzada que pugeu o un color llis. El color principal s'adaptarà automàticament en funció d'això i s'utilitzarà per a elements com les icones de les carpetes, els botons principals i els elements destacats.",
+    "Background and color" : "Fons i color",
     "Keyboard shortcuts" : "Dreceres de teclat",
     "In some cases keyboard shortcuts can interfere with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "En alguns casos, les dreceres de teclat poden interferir amb les eines d'accessibilitat. Per a permetre centrar-vos correctament en la vostra eina, podeu inhabilitar totes les dreceres de teclat aquí. Això també inhabilitarà totes les dreceres disponibles en les aplicacions.",
     "Disable all keyboard shortcuts" : "Inhabilita totes les dreceres de teclat",
@@ -85,9 +83,8 @@ OC.L10N.register(
     "Move up" : "Mou amunt",
     "Move down" : "Mou avall",
     "Custom background" : "Fons personalitzat",
+    "Plain background" : "Fons senzill",
     "Default background" : "Fons per defecte",
-    "Change color" : "Canvia el color",
-    "No background" : "Sense fons",
     "Select a background from your files" : "Seleccioneu un fons dels fitxers",
     "Select background" : "Selecciona un fons",
     "No background has been selected" : "No s'ha seleccionat cap fons",
@@ -107,11 +104,14 @@ OC.L10N.register(
     "Default app priority" : "Prioritat de l'aplicació per defecte",
     "If an app is not enabled for a user, the next app with lower priority is used." : "Si un usuari no té habilitada una aplicació, s'utilitza l'aplicació següent amb una prioritat inferior.",
     "Could not set global default apps" : "No s'han pogut definir les aplicacions per defecte globals",
+    "Select a custom color" : "Selecciona un color personalitzat",
     "Reset to default" : "Reinicialitza els valors per defecte",
     "Upload" : "Puja",
     "Remove background image" : "Suprimeix la imatge de fons",
+    "Color" : "Color",
     "Background" : "Fons",
     "Set a custom background" : "Definiu un fons personalitzat",
-    "Select a custom color" : "Selecciona un color personalitzat"
+    "Change color" : "Canvia el color",
+    "No background" : "Sense fons"
 },
 "nplurals=2; plural=(n != 1);");
