@@ -19,7 +19,7 @@ OC.L10N.register(
     "%1$s, %2$s and %3$s" : "%1$s, %2$s a %3$s",
     "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s a %4$s",
     "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s a %5$s",
-    "Education Edition" : "Edícia pre výuku",
+    "Education bundle" : "Sada pre vzdelávanie",
     "Enterprise bundle" : "Enterprise balíček",
     "Groupware bundle" : "Balíček groupware",
     "Hub bundle" : "Sada pre centrum aktivity (hub)",
@@ -38,6 +38,7 @@ OC.L10N.register(
     "Server version %s or higher is required." : "Je vyžadovaná verzia servera %s alebo vyššia.",
     "Server version %s or lower is required." : "Je vyžadovaná verzia servera %s alebo nižšia.",
     "Logged in account must be an admin, a sub admin or gotten special right to access this setting" : "Prihlásený účet musí byť správcom, podadministrátorom alebo musí mať špeciálne právo na prístup k tomuto nastaveniu.",
+    "Your current IP address doesn’t allow you to perform admin actions" : "Vaša aktuálna adresa IP vám neumožňuje vykonávať akcie správcu",
     "Logged in account must be an admin or sub admin" : "Prihlásený účet musí byť správcom alebo sub správcom.",
     "Logged in account must be an admin" : "Prihlásený účet musí byť správcom",
     "Wiping of device %s has started" : "Začalo sa mazanie zariadenia %s",
@@ -80,14 +81,21 @@ OC.L10N.register(
     "seconds ago" : "pred sekundami",
     "Empty file" : "Prázdny súbor",
     "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Modul s ID: %s neexistuje. Povoľte ho prosím vo vašom nastavení aplikácií alebo kontaktujte správcu.",
+    "Dot files are not allowed" : "Názov súboru začínajúci bodkou nie je povolený.",
+    "\"%1$s\" is a forbidden file or folder name." : "\"%1$s\" je zakázané pre súbor alebo adresár",
+    "\"%1$s\" is a forbidden prefix for file or folder names." : "\"%1$s\" je zakázaná predpona pre názov súboru alebo adresára.",
+    "\"%1$s\" is not allowed inside a file or folder name." : "\"%1$s\" nie je povolené v názve súboru alebo adresára",
+    "\"%1$s\" is a forbidden file type." : "\"%1$s\" nie je povolený typ súboru",
+    "Filenames must not end with \"%1$s\"." : "Názvy súborov nemôžu končiť na \"%1$s\".",
+    "Invalid parent path" : "Neplatná nadradená cesta",
     "File already exists" : "Súbor už existuje",
     "Invalid path" : "Neplatná cesta",
     "Failed to create file from template" : "Nemôžem vytvoriť súbor zo šablóny",
     "Templates" : "Šablóny",
-    "File name is a reserved word" : "Názov súboru je rezervované slovo.",
-    "File name contains at least one invalid character" : "Názov súboru obsahuje nepovolené znaky.",
-    "File name is too long" : "Meno súboru je veľmi dlhé.",
-    "Dot files are not allowed" : "Názov súboru začínajúci bodkou nie je povolený.",
+    "Path contains invalid segments" : "Cesta obsahuje neplatné časti",
+    "Filename is a reserved word" : "Názov súboru je rezervované slovo",
+    "Filename contains at least one invalid character" : "Názov súboru obsahuje najmenej jeden nepovolený znak",
+    "Filename is too long" : "Meno súboru je veľmi dlhé",
     "Empty filename is not allowed" : "Prázdny názov súboru nie je povolený",
     "App \"%s\" cannot be installed because appinfo file cannot be read." : "Aplikáciu \"%s\" nie je možné nainštalovať, lebo nebolo možné načítať súbor s informáciami o aplikácií.",
     "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "Aplikácia \"%s\" nie je kompatibilná s verziou servera, preto nemôže byť nainštalovaná.",
@@ -100,7 +108,7 @@ OC.L10N.register(
     "Administration settings" : "Nastavenia administrácie",
     "Settings" : "Nastavenia",
     "Log out" : "Odhlásiť sa",
-    "Users" : "Používatelia",
+    "Accounts" : "Účty",
     "Email" : "E-mail",
     "Mail %s" : "Pošta pre %s",
     "Fediverse" : "Fediverse",
@@ -118,6 +126,7 @@ OC.L10N.register(
     "Headline" : "Titul",
     "Organisation" : "Organizácia",
     "Role" : "Rola",
+    "Pronouns" : "Zámená",
     "Unknown account" : "Neznámy účet",
     "Additional settings" : "Ďalšie nastavenia",
     "Enter the database Login and name for %s" : "Zadajte prihlasovacie meno a názov databázy pre %s",
@@ -136,29 +145,55 @@ OC.L10N.register(
     "Set an admin Login." : "Nastaviť prihlasovacie meno administrátora.",
     "Set an admin password." : "Zadajte heslo administrátora.",
     "Cannot create or write into the data directory %s" : "Nemožno vytvoriť alebo zapisovať do priečinka dát %s",
-    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Backend pre sprístupnenie %s musí implementovať rozhranie OCP\\Share_Backend",
+    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Backend pre zdieľanie %s musí implementovať rozhranie OCP\\Share_Backend",
     "Sharing backend %s not found" : "Backend sprístupnenia %s nebol nájdený",
     "Sharing backend for %s not found" : "Backend sprístupnenia pre %s nebol nájdený",
-    "%1$s shared »%2$s« with you and wants to add:" : "%1$s vám sprístupnil »%2$s« s poznámkou:",
-    "%1$s shared »%2$s« with you and wants to add" : "%1$s vám sprístupnil »%2$s« s poznámkou",
-    "»%s« added a note to a file shared with you" : "»%s« pridal poznámku k súboru ktorý s Vami zdieľa",
-    "Open »%s«" : "Otvoriť »%s«",
+    "%1$s shared %2$s with you" : "%1$s s vami zdieľal %2$s ",
+    "Open %s" : "Otvoriť %s",
     "%1$s via %2$s" : "%1$s cez %2$s",
+    "Passwords are enforced for link and mail shares" : "Heslo je vyžadováné pre zdieľanie odkazom alebo e-mailom",
+    "Share recipient is not a valid user" : "Príjemca zdieľania nie je platným uživateľom",
+    "Share recipient is not a valid group" : "Príjemca zdieľania nie je platnou skupinou",
+    "Share recipient should be empty" : "Príjemca zdieľania musí byť prázdny",
+    "Share recipient should not be empty" : "Príjemca zdieľania nemôže byť prázdny",
+    "Share recipient is not a valid circle" : "Príjemca zdieľania nie je platný kruh",
+    "Unknown share type" : "Neplatný typ sprístupnenia",
+    "Share initiator must be set" : "Musí byť nastavený iniciátor zdieľania",
+    "Cannot share with yourself" : "Nie je možné zdieľanie so sebou samým",
+    "Shared path must be set" : "Musí byť nastavená zdieľaná cesta",
+    "Shared path must be either a file or a folder" : "Zdieľaná cesta musí byť súbor alebo adresár",
+    "You cannot share your root folder" : "Nemôžete zdieľať váš koreňový adresár",
     "You are not allowed to share %s" : "Nemôžete sprístupniť %s",
+    "Valid permissions are required for sharing" : "Pre zdieľanie sú potrebné korektné práva",
     "Cannot increase permissions of %s" : "Nie je možné navýšiť oprávnenia pre %s",
+    "Shares need at least read permissions" : "Zdieľanie vyžaduje minimálne práva na čítanie",
     "Files cannot be shared with delete permissions" : "Súbory nie je možné sprístupňovať s oprávneniami na odstránenie",
     "Files cannot be shared with create permissions" : "Súbory nie je možné sprístupňovať s oprávneniami na vytváranie",
     "Expiration date is in the past" : "Dátum konca platnosti je v minulosti",
+    "Expiration date is enforced" : "Dátum expirácie je vyžadovaný",
     "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Nie je možné nastaviť dátum konca platnosti viac ako %s deň v budúcnosti","Nie je možné nastaviť dátum konca platnosti viac ako %s dní v budúcnosti","Nie je možné nastaviť dátum konca platnosti viac ako %s dní v budúcnosti","Nie je možné nastaviť dátum konca platnosti viac ako %s dní v budúcnosti"],
     "Sharing is only allowed with group members" : "Zdieľanie je možné iba s členmi skupiny",
     "Sharing %s failed, because this item is already shared with the account %s" : "Zdieľanie %s zlyhalo, pretože táto položka už je užívateľovi %s zozdieľaná.",
-    "%1$s shared »%2$s« with you" : "%1$s vám sprístupnil »%2$s«",
-    "%1$s shared »%2$s« with you." : "%1$s vám sprístupnil »%2$s«.",
-    "Click the button below to open it." : "Pre otvorenie klienta kliknite na tlačítko nižšie.",
-    "The requested share does not exist anymore" : "Požadované sprístupnenie už neexistuje",
+    "Group sharing is now allowed" : "Zdieľanie pre skupiny je teraz povolené",
+    "Sharing is only allowed within your own groups" : "Zdieľanie je povolené len pre vašu vlastnú skupinu",
+    "Path is already shared with this group" : "Cesta je už zdieľaná s touto skupinou",
+    "Link sharing is not allowed" : "Zdieľanie odkazu nie je povolené",
+    "Public upload is not allowed" : "Verejné nahrávanie nie je povolené",
+    "Path contains files shared with you" : "Cesta obsahuje súbory zdieľané s vami",
+    "Sharing is disabled" : "Zdieľanie je zakázané",
+    "Sharing is disabled for you" : "Zdieľanie je pre vás zakázané",
+    "Cannot share with the share owner" : "Nie je možné zdieľať s vlastníkom",
+    "Share does not have a full ID" : "Zdieľanie nemá plné ID",
+    "Cannot change share type" : "Nie je možné zmeniť typ zdieľania",
+    "Can only update recipient on user shares" : "Príjemcu je možné aktualizovať iba v užívateľských zdieľaniach",
+    "Invalid share recipient" : "Neplatný príjemca zdieľania",
+    "Group \"%s\" does not exist" : "Skupina \"%s\" neexistuje",
+    "The requested share does not exist anymore" : "Požadované zdieľanie už neexistuje",
     "The requested share comes from a disabled user" : "Požadované zdieľanie pochádza od zakázaného užívateľa.",
     "The user was not created because the user limit has been reached. Check your notifications to learn more." : "Bol dosiahnutý limit používateľov a používateľ nebol vytvorený. Pozrite sa do upozornení pre viac informácií.",
     "Could not find category \"%s\"" : "Nemožno nájsť danú kategóriu \"%s\"",
+    "Input text" : "Vstupný text",
+    "The input text" : "Vstupný text",
     "Sunday" : "Nedeľa",
     "Monday" : "Pondelok",
     "Tuesday" : "Utorok",
@@ -216,8 +251,6 @@ OC.L10N.register(
     "Login canceled by app" : "Prihlásenie bolo zrušené aplikáciou",
     "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "Aplikáciu \"%1$s\" nie je možné inštalovať, pretože nie sú splnené nasledovné závislosti: %2$s",
     "a safe home for all your data" : "bezpečný domov pre všetky vaše dáta",
-    "File is currently busy, please try again later" : "Súbor sa práve používa, skúste prosím neskôr",
-    "Cannot download file" : "Nemožno stiahnuť súbor",
     "Application is not enabled" : "Aplikácia nie je zapnutá",
     "Authentication error" : "Chyba autentifikácie",
     "Token expired. Please reload page." : "Token vypršal. Obnovte, prosím, stránku.",
@@ -250,7 +283,6 @@ OC.L10N.register(
     "Your data directory must be an absolute path." : "Priečinok s dátami musí byť zadaný ako absolútna cesta.",
     "Check the value of \"datadirectory\" in your configuration." : "Skontrolujte hodnotu \"datadirectory\" vo vašej konfigurácii.",
     "Your data directory is invalid." : "Priečinok pre dáta je neplatný.",
-    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Uistite sa, že v koreňovom adresári sa nachádza súbor s názvom \".ocdata\".",
     "Action \"%s\" not supported or implemented." : "Akcia \"%s\" nie je podporovaná alebo implementovaná.",
     "Authentication failed, wrong token or provider ID given" : "Autentifikácia zlyhala, bol zadaný neplatný token alebo ID poskytovateľa",
     "Parameters missing in order to complete the request. Missing Parameters: \"%s\"" : "Pre dokončenie požiadavky chýbajú parametre.  Chýbajúce parametre: \"%s\"",
@@ -262,19 +294,98 @@ OC.L10N.register(
     "Storage connection error. %s" : "Chyba pripojenia k úložisku. %s",
     "Storage is temporarily not available" : "Úložisko je dočasne nedostupné",
     "Storage connection timeout. %s" : "Vypršanie pripojenia k úložisku. %s",
+    "To allow this check to run you have to make sure that your Web server can connect to itself. Therefore it must be able to resolve and connect to at least one of its `trusted_domains` or the `overwrite.cli.url`. This failure may be the result of a server-side DNS mismatch or outbound firewall rule." : "Ak chcete povoliť spustenie tejto kontroly, musíte sa uistiť, že váš webový server sa môže pripojiť sám k sebe. Preto musí byť schopný rozpoznať a pripojiť sa aspoň k jednej zo svojich `trusted_domains` alebo `overwrite.cli.url`.  Výsledkom nesprávneho nastavenia môže byť nesúlad DNS na strane servera alebo pravidla brány firewall pre výstup.",
+    "Transcribe audio" : "Prepísať zvuk",
+    "Transcribe the things said in an audio" : "Prepísať veci povedané vo zvuku",
+    "Audio input" : "Audio vstup",
+    "The audio to transcribe" : "Zvuk pre prepísanie",
+    "Transcription" : "Prepis",
+    "The transcribed text" : "Prepísaný text",
+    "Chat message" : "Správa chatu",
+    "Confirmation" : "Potvrdenie",
+    "Context write" : "Kontextový zápis",
+    "Writes text in a given style based on the provided source material." : "Napíše text v danom štýle na základe poskytnutého zdrojového materiálu.",
+    "Writing style" : "Štýl písania",
+    "Demonstrate a writing style that you would like to immitate" : "Ukážte štýl písania, ktorý by ste chceli napodobniť",
+    "Source material" : "Zdrojový materiál",
+    "The content that would like to be rewritten in the new writing style" : "Obsah, ktorý by bol prepísaný do nového štýlu písania",
+    "Generated text" : "Vygenerovaný text",
+    "The generated text with content from the source material in the given style" : "Vygenerovaný text s obsahom zo zdrojového materiálu v danom štýle",
+    "Emoji generator" : "Generátor emotikonov",
+    "Takes text and generates a representative emoji for it." : "Zoberie text a vygeneruje pre neho reprezentatívny emotikon.",
+    "The text to generate an emoji for" : "Text pre ktorý vygeneruje emotikon",
+    "Generated emoji" : "Vygenerované emotikony",
+    "The generated emoji based on the input text" : "Vygenerovaný emotikon založený na vstupnom texte",
+    "Generate image" : "Vygenerovať obrázok",
+    "Generate an image from a text prompt" : "Vygenerovať obrázok na základe textového zadania",
+    "Prompt" : "Zadanie",
+    "Describe the image you want to generate" : "Popíšte obrázok ktorý chcete vygenerovať",
+    "Number of images" : "Počet obrázkov",
+    "How many images to generate" : "Koľko obrázkov sa bude generovať",
+    "Output images" : "Výstupné obrázky",
+    "The generated images" : "Vygenerované obrázky",
+    "Generated reply" : "Vygenerovaná odpoveď",
+    "Chat" : "Chat",
+    "Chat with the assistant" : "Chat s asistentom",
+    "System prompt" : "Systémová výzva",
+    "Chat history" : "História chatu",
+    "Response message" : "Správa s odpoveďou",
+    "Tool message" : "Správa nástroja",
+    "Available tools" : "Dostupné nástroje",
+    "Formalize text" : "Formalizovať text",
+    "Formalized text" : "Formalizovaný text",
+    "The formalized text" : "Formalizovaný text",
+    "Generate a headline" : "Vygenerovať titulok",
+    "Generates a possible headline for a text." : "Generuje možný nadpis pre text.",
+    "Original text" : "Originálny text",
+    "The original text to generate a headline for" : "Originálny text pre ktorý sa vygeneruje titulok",
+    "The generated headline" : "Vygenerovaný titulok",
+    "Text" : "Text",
+    "Corrections" : "Opravy",
+    "Reformulate text" : "Preformulovať text",
+    "Takes a text and reformulates it" : "Zoberie text a preformuluje ho",
+    "Write a text that you want the assistant to reformulate" : "Napíšte text pre ktorý chcete aby asistent preforumuloval",
+    "Reformulated text" : "Preformulovaný text",
+    "The reformulated text, written by the assistant" : "Preformulovaný text, ktorý napísal asistent",
+    "Simplify text" : "Zjednodušiť text",
+    "Takes a text and simplifies it" : "Zobrať text a zjednodušiť ho",
+    "Write a text that you want the assistant to simplify" : "Napíšte text ktorý chcete od asistenta zjednodušiť",
+    "Simplified text" : "Zjednodušený text",
+    "The simplified text" : "Zjednodušený text",
+    "Summarize" : "Zhrnutie",
+    "Summarizes a text" : "Zhrnutie textu",
+    "The original text to summarize" : "Originálny text pre zhrnutie",
+    "Summary" : "Súhrn",
+    "The generated summary" : "Vygenerované zhrnutie",
+    "Extract topics" : "Extrahovať témy",
+    "Extracts topics from a text and outputs them separated by commas" : "Vyextrahovať témy z textu a vypísať ich ako zoznam oddelený čiarkami",
+    "The original text to extract topics from" : "Originálny text z ktorého sa vyextrahujú témy",
+    "Topics" : "Témy",
+    "The list of extracted topics" : "Zoznam vyextrahovaných tém",
+    "Translate" : "Preložiť",
+    "Translate text from one language to another" : "Preložiť text z jedného jazyka do druhého",
+    "Origin text" : "Pôvodný text",
+    "The text to translate" : "Text pre preklad",
+    "Origin language" : "Pôvodný jazyk",
+    "The language of the origin text" : "Jazyk pôvodného textu",
+    "Target language" : "Cieľový jazyk",
+    "The desired language to translate the origin text in" : "Požadovaný jazyk, do ktorého sa má preložiť pôvodný text",
+    "Result" : "Výsledok",
+    "The translated text" : "Preložený text",
     "Free prompt" : "Bezplatný formulár",
     "Runs an arbitrary prompt through the language model." : "Spúšťa ľubovoľný príkaz cez jazykový model.",
     "Generate headline" : "Generovať nadpis",
-    "Generates a possible headline for a text." : "Generuje možný nadpis pre text.",
-    "Summarize" : "Zhrnutie",
     "Summarizes text by reducing its length without losing key information." : "Zhrňuje text tým, že znižuje jeho dĺžku bez straty kľúčových informácií.",
-    "Extract topics" : "Extrahovať témy",
     "Extracts topics from a text and outputs them separated by commas." : "Extrahuje témy z textu a vypisuje ich oddelené čiarkami.",
-    "404" : "404",
+    "Education Edition" : "Edícia pre výuku",
     "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "Prihlásený používateľ musí byť správcom, podadministrátorom alebo musí mať špeciálne právo na prístup k tomuto nastaveniu",
     "Logged in user must be an admin or sub admin" : "Prihlásený používateľ musí byť správcom alebo správcom pre čiastkovú oblasť.",
     "Logged in user must be an admin" : "Prihlásený používateľ musí byť správca",
+    "File name is a reserved word" : "Názov súboru je rezervované slovo.",
+    "File name contains at least one invalid character" : "Názov súboru obsahuje nepovolené znaky.",
+    "File name is too long" : "Meno súboru je veľmi dlhé.",
     "Help" : "Pomoc",
+    "Users" : "Používatelia",
     "Unknown user" : "Neznámy používateľ",
     "Enter the database username and name for %s" : "Zadajte užívateľské meno a názov databázy pre %s",
     "Enter the database username for %s" : "Zadajte užívateľské meno databázy pre %s",
@@ -282,7 +393,14 @@ OC.L10N.register(
     "Oracle username and/or password not valid" : "Používateľské meno a/alebo heslo pre Oracle databázu je neplatné",
     "PostgreSQL username and/or password not valid" : "Používateľské meno a/alebo heslo pre PostgreSQL databázu je neplatné",
     "Set an admin username." : "Zadajte používateľské meno administrátora.",
-    "Sharing %s failed, because this item is already shared with user %s" : "Sprístupnenie %s zlyhalo, táto položka už je používateľovi %s zozdieľaná",
+    "%1$s shared »%2$s« with you and wants to add:" : "%1$s vám sprístupnil »%2$s« s poznámkou:",
+    "%1$s shared »%2$s« with you and wants to add" : "%1$s vám sprístupnil »%2$s« s poznámkou",
+    "»%s« added a note to a file shared with you" : "»%s« pridal poznámku k súboru ktorý s Vami zdieľa",
+    "Open »%s«" : "Otvoriť »%s«",
+    "Sharing %s failed, because this item is already shared with user %s" : "Zdieľanie %s zlyhalo, táto položka už je používateľovi %s zozdieľaná",
+    "%1$s shared »%2$s« with you" : "%1$s vám sprístupnil »%2$s«",
+    "%1$s shared »%2$s« with you." : "%1$s vám sprístupnil »%2$s«.",
+    "Click the button below to open it." : "Pre otvorenie klienta kliknite na tlačítko nižšie.",
     "The username is already being used" : "Meno používateľa je už použité",
     "Could not create user" : "Nepodarilo sa vytvoriť používateľa",
     "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "V mene užívateľa je možné použiť iba nasledovné znaky: \"a-z\", \"A-Z\", \"0-9\", medzery a \"_.@-'\"",
@@ -291,9 +409,10 @@ OC.L10N.register(
     "Username must not consist of dots only" : "Používateľské meno sa nesmie skladať len z bodiek",
     "Username is invalid because files already exist for this user" : "Používateľské meno je neplatné, pretože pre tohto používateľa už existujú súbory",
     "User disabled" : "Používateľ zakázaný",
-    "PostgreSQL >= 9 required." : "Vyžadované PostgreSQL >= 9.",
-    "Please upgrade your database version." : "Prosím, aktualizujte verziu svojej databázy.",
+    "File is currently busy, please try again later" : "Súbor sa práve používa, skúste prosím neskôr",
+    "Cannot download file" : "Nemožno stiahnuť súbor",
     "Your data directory is readable by other users." : "Váš priečinok s dátami je prístupný na čítanie ostatným užívateľom.",
-    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Prosím, zmeňte oprávnenia na 0770, aby tento priečinok nemohli ostatní používatelia otvoriť."
+    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Prosím, zmeňte oprávnenia na 0770, aby tento priečinok nemohli ostatní používatelia otvoriť.",
+    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Uistite sa, že v koreňovom adresári sa nachádza súbor s názvom \".ocdata\"."
 },
 "nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
